<?php

// find out how long ago a job was posted
if(!function_exists('how_long_ago')) {
	function how_long_ago($timestamp) {
	  $difference = time() - $timestamp;

	  if($difference >= 60*60*24*365){        // if more than a year ago
	    $int = intval($difference / (60*60*24*365));
	    $s = ($int > 1) ? 's' : '';
	    $r = $int . ' year' . $s . ' ago';
	  } elseif($difference >= 60*60*24*7*5){  // if more than five weeks ago
	    $int = intval($difference / (60*60*24*30));
	    $s = ($int > 1) ? 's' : '';
	    $r = $int . ' month' . $s . ' ago';
	  } elseif($difference >= 60*60*24*7){        // if more than a week ago
	    $int = intval($difference / (60*60*24*7));
	    $s = ($int > 1) ? 's' : '';
	    $r = $int . ' week' . $s . ' ago';
	  } elseif($difference >= 60*60*24){      // if more than a day ago
	    $int = intval($difference / (60*60*24));
	    $s = ($int > 1) ? 's' : '';
	    $r = $int . ' day' . $s . ' ago';
	  } else {                                // if less than a day ago
	  	$r = 'Today';
	  }
	  return $r;
	}
}

// insert training links into the job description where they are relevant
if (!function_exists('cb_training_inline')) {
	function cb_training_inline($text) {
		
	}
}

// highlight search terms based on cookie
if (!function_exists('cb_search_highlight')) {
	function cb_search_highlight($text) {
		if (isset($_COOKIE['search_keyword'])) {
			$keyword = $_COOKIE['search_keyword'];
			$keyworduc = ucwords(urldecode($_COOKIE['search_keyword']));
			$text = str_replace(array("$keyword", "$keyworduc"), array("<span class=\"highlight\">$keyword</span>", "<span class=\"highlight\">$keyworduc</span>"), $text);
		}
		if (isset($_COOKIE['search_location'])) {
			$location = $_COOKIE['search_location'];
			$locationuc = ucwords(urldecode($_COOKIE['search_location']));
			$text = str_replace(array("$location", "$locationuc", "<span class=\"highlight\"><span class=\"highlight\">", '</span></span>'), array("<span class=\"highlight\">$location</span>", "<span class=\"highlight\">$locationuc</span>", "<span class=\"highlight\">", '</span>'), $text);
		}
		return $text;
	}
}

// clean up some bad html in the descriptions
if(!function_exists('cb_clean_desc')) {
	function cb_clean_desc($description) {
		$description = htmlspecialchars_decode($description);
		$description = str_replace(array('<b>','<i>','<center>','</b>','</i>','</center>'), array('<strong>','<em>','','</strong>','</em>',''), $description);
		$description = str_replace(array('<p><strong>&#160;</strong>&nbsp;</p>','<p>&nbsp;</p>'), array('',''), $description);
		$description = str_replace(array('&#160;','  '), array(' ',' '), $description);
		$description = str_replace(array("’"), array(","), $description);
		return $description;
	}
}

// pagination functions
if(!function_exists('cb_pagination')) {
	function cb_pagination($page_num,$pages,$cb_jobs_perpage,$url) {
		$adjacents = 3;
		$prev = $page_num - 1;							//previous page is page - 1
		$next = $page_num + 1;							//next page is page + 1
		$lastpage = ceil($pages);		//lastpage is = total pages / items per page, rounded up.
		$lpm1 = $lastpage - 1;						//last page minus 1
		
		$pagination = '';
		
		if($lastpage > 1) {
		
			$pagination .= "<p id=\"paginglabel\" class=\"audible\">Result pages</p>\n
            <ul role=\"navigation\" aria-labelledby=\"paginglabel\">\n";
			//previous button
			if ($page_num > 1) 
				$pagination.= "<li><a href=\"".$url['results_root']."/page/$prev/".$url['searchquery']."\">« previous</a></li>";
			else
				$pagination.= "<li><span class=\"disabled\">« previous</span></li>";
			//pages				
			//not enough pages to bother breaking it up
			if ($lastpage < 7 + ($adjacents * 2)) {	
				for ($counter = 1; $counter <= $lastpage; $counter++) {
					if ($counter == $page_num)
						$pagination .= "<li><p><span class=\"audible\">You're currently viewing page </span>$counter</p></li>";
					else
						$pagination.= "<li><a href=\"".$url['results_root']."/page/$counter/".$url['searchquery']."\">$counter</a></li>";
				}
			} elseif ($lastpage > 5 + ($adjacents * 2)) {
				//close to beginning; only hide later pages
				if($page_num < 1 + ($adjacents * 2)) {
					for ($counter = 1; $counter < 4 + ($adjacents * 2); $counter++) {
						if ($counter == $page_num)
							$pagination .= "<li><p><span class=\"audible\">You're currently viewing page </span>$counter</p></li>";
						else
							$pagination .= "<li><a href=\"".$url['results_root']."/page/$counter/".$url['searchquery']."\"><span class=\"audible\">Page </span>$counter</a></li>";
					}
				} elseif ($lastpage - ($adjacents * 2) > $page_num && $page_num > ($adjacents * 2)) {
					$pagination.= "<li><a href=\"".$url['results_root']."/page/1/".$url['searchquery']."\"><span class=\"audible\">Page </span>1</a></li>";
					$pagination.= "<li><a href=\"".$url['results_root']."/page/2/".$url['searchquery']."\"><span class=\"audible\">Page </span>2</a></li>";
					$pagination.= "<li>...</li>";
					for ($counter = $page_num - $adjacents; $counter <= $page_num + $adjacents; $counter++) {
						if ($counter == $page_num)
							$pagination .= "<li><p><span class=\"audible\">You're currently viewing page </span>$counter</p></li>";
						else
							$pagination .= "<li><a href=\"".$url['results_root']."/page/$counter/".$url['searchquery']."\"><span class=\"audible\">Page </span>$counter</a></li>";
					}
				} else {
					$pagination .= "<li><a href=\"".$url['results_root']."/page/1/".$url['searchquery']."\><span class=\"audible\">Page </span>1</a></li>";
					$pagination .= "<li><a href=\"".$url['results_root']."/page/2/".$url['searchquery']."\><span class=\"audible\">Page </span>2</a></li>";
					$pagination.= "<li>...</li>";
					for ($counter = $lastpage - (2 + ($adjacents * 2)); $counter <= $lastpage; $counter++) {
						if ($counter == $page_num)
							$pagination .= "<li><p><span class=\"audible\">You're currently viewing page </span>$counter</p></li>";
						else
							$pagination .= "<li><a href=\"".$url['results_root']."/page/$counter/".$url['searchquery']."\"><span class=\"audible\">Page </span>$counter</a></li>";
					}
				}
			}
			//next button
			if ($page_num < $counter - 1) 
				$pagination.= "<li><a href=\"".$url['results_root']."/page/$next/".$url['searchquery']."\">next »</a></li>";
			else
				//$pagination.= '';
				$pagination.= "<li><span class=\"disabled\">next »</span></li>";
			$pagination.= "</ul>\n";		
		}
		return $pagination;
	}
}

?>