<?php
/*
Plugin Name: CareerBuilder Jobs
Plugin URI: 
Description: Host your own job board powered by CareerBuilder. Host your own job board powered by CareerBuilder.com. This plugin allows users to search for jobs, browse jobs by location or by category, get possibly related jobs through our recommendation technology, and link directly to the application process for each job. You will need to register and obtain a <a href="http://api.careerbuilder.com/RequestDevKey.aspx">developer key</a>.
Version: 0.9.1
Author: CareerBuilder
Author URI: http://wordpress.careerbuildermarketing.com
License: GPL2
*/

/*  Copyright 2010  CareerBuilder, LLC  (email : marketingtechnology@careerbuilder.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/**
 * Main Job Search plugin class
 */
class CB_JobSearch {
	
	/**      
	 * actions for plugin initialization
	 */
	function __construct() {
		$plugin_dir = basename(dirname(__FILE__));
		$this->theme_dir = get_bloginfo( 'template_url' );
		$this->theme_path = get_theme_root().'/'.get_template();
		load_plugin_textdomain( 'careerbuilder_jobs', 'wp-content/plugins/' . $plugin_dir, $plugin_dir );
		$options = get_option('careerbuilder_jobs_options');
		if ( isset ( $options ) ) {
			$this->cb_developer_key = $options['cb_developer_key'];
		}
		if ($cb_developer_key) {
			//global $cbDeveloper;
		}
	}
	
	/**      
	 * actions for plugin deactivation
	 */
	function deactivate() {
		CB_JobSearch::job_flush_rewrite();
	}
		
	/**
	 * @return acceptable querystring values
	 */
	function job_no_prefix($public_query_vars) {
		$public_query_vars[] = 'job_did';
		$public_query_vars[] = 'job_no_prefix';
		$public_query_vars[] = 'job_company';
		$public_query_vars[] = 'job_location';
		$public_query_vars[] = 'job_category';
		$public_query_vars[] = 'feed';
		$public_query_vars[] = 'page';
		$public_query_vars[] = 'keyword';
		$public_query_vars[] = 'location';
  	return $public_query_vars;
	}
	
	/**      
	 * Flush rewrite rules to accept plugin-specific ones
	 * This also runs on plugin deactivation to remove plugin-specific rules
	 */
	function job_flush_rewrite() {
		global $wp_rewrite;
		$wp_rewrite->flush_rules();
	}
	
	/**      
	 * Generate plugin-specific rewrite rules
	 */
	function job_add_rewrite_rules( $wp_rewrite ) {
		$options = get_option('careerbuilder_jobs_options');
		$cb_jobresults_page = $options['cb_jobresults_page'];
		$cb_jobdetails_page = $options['cb_jobdetails_page'];
		$cb_permalinks = $options['cb_permalinks'];
		// rewrite rules for result, details, feed, paged, location, and category URLs
		$job_detail_rules = array( $cb_jobdetails_page."/(.+)" => "index.php?pagename=$cb_jobdetails_page&job_did=" . $wp_rewrite->preg_index(1) );
		$job_paged_rules = array( $cb_jobresults_page."/page/(.+)" => "index.php?pagename=$cb_jobresults_page&page=" . $wp_rewrite->preg_index(1) );
		$job_feed_rules = array( $cb_jobresults_page.'/feed' => 'index.php?pagename=$cb_jobresults_page&feed=jobs' );
		// if there is a prefix
		if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
			$cb_location_prefix = $options['cb_location_prefix'];
			$cb_category_prefix = $options['cb_category_prefix'];
			$cb_company_prefix = $options['cb_company_prefix'];
			if ( $cb_permalinks == 1 ) {
				// rules for directory with prefixes
				$company_paged_rules = array( $cb_jobresults_page.'/'.$cb_company_prefix."/(.+)/page/(.+)" => "index.php?pagename=$cb_jobresults_page&job_company=" . $wp_rewrite->preg_index(1) . "&page=" . $wp_rewrite->preg_index(2) );				
				$company_feed_rules = array( $cb_jobresults_page.'/'.$cb_company_prefix.'/(.+)/feed' => 'index.php?pagename=$cb_jobresults_page&job_company=' . $wp_rewrite->preg_index(1).'&feed=jobs' );
				$company_rules = array( $cb_jobresults_page.'/'.$cb_company_prefix."/(.+)" => "index.php?pagename=$cb_jobresults_page&job_company=" . $wp_rewrite->preg_index(1) );
				$loc_paged_rules = array( $cb_jobresults_page.'/'.$cb_location_prefix."/(.+)/page/(.+)" => "index.php?pagename=$cb_jobresults_page&job_location=" . $wp_rewrite->preg_index(1) . "&page=" . $wp_rewrite->preg_index(2) );
				$loc_feed_rules = array( $cb_jobresults_page.'/'.$cb_location_prefix.'/(.+)/feed' => 'index.php?pagename=$cb_jobresults_page&job_location=' . $wp_rewrite->preg_index(1).'&feed=jobs' );
				$loc_rules = array( $cb_jobresults_page.'/'.$cb_location_prefix."/(.+)" => "index.php?pagename=$cb_jobresults_page&job_location=" . $wp_rewrite->preg_index(1) );
				$cat_paged_rules = array( $cb_jobresults_page.'/'.$cb_category_prefix."/(.+)/page/(.+)" => "index.php?pagename=$cb_jobresults_page&job_category=" . $wp_rewrite->preg_index(1) . "&page=" . $wp_rewrite->preg_index(2) );
				$cat_feed_rules = array( $cb_jobresults_page.'/'.$cb_category_prefix.'/(.+)/feed' => 'index.php?pagename=$cb_jobresults_page&job_category=' . $wp_rewrite->preg_index(1).'&feed=jobs' );
				$cat_rules = array( $cb_jobresults_page.'/'.$cb_category_prefix."/(.+)" => "index.php?pagename=$cb_jobresults_page&job_category=" . $wp_rewrite->preg_index(1) );
				// add these rules to the WP rewrite rules, more specific ones followed by more general ones
				$wp_rewrite->rules = $job_detail_rules + $job_paged_rules + $job_feed_rules + $company_paged_rules + $company_feed_rules + $company_rules + $loc_paged_rules + $loc_feed_rules + $loc_rules + $cat_paged_rules + $cat_feed_rules + $cat_rules + $wp_rewrite->rules;
			} else if ( $cb_permalinks == 3 ) {
				// rules for hyphenated with prefixes
				$company_paged_rules = array( $cb_jobresults_page.'-at-'.$cb_company_prefix."/(.+)/page/(.+)" => "index.php?pagename=$cb_jobresults_page&job_company=" . $wp_rewrite->preg_index(1) . "&page=" . $wp_rewrite->preg_index(2) );				
				$company_feed_rules = array( $cb_jobresults_page.'-at-'.$cb_company_prefix.'/(.+)/feed' => 'index.php?pagename=$cb_jobresults_page&job_company=' . $wp_rewrite->preg_index(1).'&feed=jobs' );
				$company_rules = array( $cb_jobresults_page.'-at-'.$cb_company_prefix."/(.+)" => "index.php?pagename=$cb_jobresults_page&job_company=" . $wp_rewrite->preg_index(1) );
				$loc_paged_rules = array( $cb_jobresults_page.'-by-'.$cb_location_prefix."/(.+)/page/(.+)" => "index.php?pagename=$cb_jobresults_page&job_location=" . $wp_rewrite->preg_index(1) . "&page=" . $wp_rewrite->preg_index(2) );
				$loc_feed_rules = array( $cb_jobresults_page.'-by-'.$cb_location_prefix.'/(.+)/feed' => 'index.php?pagename=$cb_jobresults_page&job_location=' . $wp_rewrite->preg_index(1).'&feed=jobs' );
				$loc_rules = array( $cb_jobresults_page.'-by-'.$cb_location_prefix."/(.+)" => "index.php?pagename=$cb_jobresults_page&job_location=" . $wp_rewrite->preg_index(1) );
				$cat_paged_rules = array( $cb_jobresults_page.'-by-'.$cb_category_prefix."/(.+)/page/(.+)" => "index.php?pagename=$cb_jobresults_page&job_category=" . $wp_rewrite->preg_index(1) . "&page=" . $wp_rewrite->preg_index(2) );
				$cat_feed_rules = array( $cb_jobresults_page.'-by-'.$cb_category_prefix.'/(.+)/feed' => 'index.php?pagename=$cb_jobresults_page&job_category=' . $wp_rewrite->preg_index(1).'&feed=jobs' );
				$cat_rules = array( $cb_jobresults_page.'-by-'.$cb_category_prefix."/(.+)" => "index.php?pagename=$cb_jobresults_page&job_category=" . $wp_rewrite->preg_index(1) );
				// add these rules to the WP rewrite rules, more specific ones followed by more general ones
				$wp_rewrite->rules = $job_detail_rules + $job_paged_rules + $job_feed_rules + $company_paged_rules + $company_feed_rules + $company_rules + $loc_paged_rules + $loc_feed_rules + $loc_rules + $cat_paged_rules + $cat_feed_rules + $cat_rules + $wp_rewrite->rules;
			}
		// if there is no prefix
		} else {
			$cb_company_prefix = $options['cb_company_prefix'];
			if ( $cb_permalinks == 2 ) {
				// rules for directory
				$company_paged_rules = array( $cb_jobresults_page.'/'.$cb_company_prefix."/(.+)/page/(.+)" => "index.php?pagename=$cb_jobresults_page&job_company=" . $wp_rewrite->preg_index(1) . "&page=" . $wp_rewrite->preg_index(2) );
				$company_feed_rules = array( $cb_jobresults_page.'/'.$cb_company_prefix.'/(.+)/feed' => 'index.php?pagename=$cb_jobresults_page&job_company=' . $wp_rewrite->preg_index(1).'&feed=jobs' );
				$company_rules = array( $cb_jobresults_page.'/'.$cb_company_prefix."/(.+)" => "index.php?pagename=$cb_jobresults_page&job_company=" . $wp_rewrite->preg_index(1) );
				$dir_paged_rules = array( $cb_jobresults_page."/(.+)/page/(.+)" => "index.php?pagename=$cb_jobresults_page&job_no_prefix=" . $wp_rewrite->preg_index(1) . "&page=" . $wp_rewrite->preg_index(2) );
				$dir_feed_rules = array( $cb_jobresults_page.'/feed' => 'index.php?pagename=$cb_jobresults_page&job_no_prefix=' . $wp_rewrite->preg_index(1).'&feed=jobs' );
				$dir_rules = array( $cb_jobresults_page."/(.+)" => "index.php?pagename=$cb_jobresults_page&job_no_prefix=" . $wp_rewrite->preg_index(1) );
				// add these rules to the WP rewrite rules, more specific ones followed by more general ones
				$wp_rewrite->rules = $job_detail_rules + $job_paged_rules + $job_feed_rules + $company_paged_rules + $company_feed_rules + $company_rules + $dir_paged_rules + $dir_feed_rules + $dir_rules + $wp_rewrite->rules;					
			} else if ( $cb_permalinks == 4 ) {
				// rules for hyphenated
				$company_paged_rules = array( $cb_jobresults_page."-at-(.+)/page/(.+)" => "index.php?pagename=$cb_jobresults_page&job_company=" . $wp_rewrite->preg_index(1) . "&page=" . $wp_rewrite->preg_index(2) );
				$company_feed_rules = array( $cb_jobresults_page.'-at-(.+)/feed' => 'index.php?pagename=$cb_jobresults_page&job_company=' . $wp_rewrite->preg_index(1).'&feed=jobs' );
				$company_rules = array( $cb_jobresults_page."-at-/(.+)" => "index.php?pagename=$cb_jobresults_page&job_company=" . $wp_rewrite->preg_index(1) );
				$hyph_paged_rules = array( $cb_jobresults_page."-in-(.+)/page/(.+)" => "index.php?pagename=$cb_jobresults_page&job_no_prefix=" . $wp_rewrite->preg_index(1) . "&page=" . $wp_rewrite->preg_index(2) );
				$hyph_feed_rules = array( $cb_jobresults_page.'-in-(.+)/feed' => 'index.php?pagename=$cb_jobresults_page&job_no_prefix=' . $wp_rewrite->preg_index(1).'&feed=jobs' );
				$hyph_rules = array( $cb_jobresults_page."-in-(.+)" => "index.php?pagename=$cb_jobresults_page&job_no_prefix=" . $wp_rewrite->preg_index(1) );
				// add these rules to the WP rewrite rules, more specific ones followed by more general ones
				$wp_rewrite->rules = $job_detail_rules + $job_paged_rules + $job_feed_rules + $company_paged_rules + $company_feed_rules + $company_rules + $hyph_paged_rules + $hyph_feed_rules + $hyph_rules + $wp_rewrite->rules;	
			}
		}
	}
	
	/**      
	 * Set WordPress title tags for job details and job results
	 */
	function replace_title( $title ) {
		global $wp_query, $wp_rewrite, $posts;
		$options = get_option('careerbuilder_jobs_options');
		$cb_jobresults_page = $options['cb_jobresults_page'];
		$cb_jobdetails_page = $options['cb_jobdetails_page'];
		// title for job results page
		if ( is_page("$cb_jobresults_page") ) {
			$gen_value = strtolower(get_query_var('job_no_prefix'));
			$search_keyword = get_query_var('keyword');
			$search_location = get_query_var('location');
			if ( !$gen_value ) {
				$location_value = strtolower(get_query_var('job_location'));
				$category_value = strtolower(get_query_var('job_category'));
				$category_value = CB_JobSearch::get_cb_category( $category_value );
				$company_value = strtolower(get_query_var('job_company'));
			} else {
				$category_value = CB_JobSearch::get_cb_category( $gen_value );
				if ( $category_value != false ) {
					$category_value = strtolower(get_query_var('job_no_prefix'));
				} else {
					$location_value = strtolower(get_query_var('job_no_prefix'));
				}
			}
			// location page
			if ( $location_value ) {
				// with a search keyword
				if ( $search_keyword ) {
					$location_value = str_replace(',','_',$location_value);
					$location_value = explode('_', $location_value);
					if (count($location_value) > 1) {
						if (strlen($location_value[1]) == 2) {
							$location_value[1] = strtoupper($location_value[1]);
						}
						$location_value = implode(', ', $location_value);
					} else {
						$location_value = $location_value[0];
					}
					$location_value = str_replace('-',' ',$location_value);
					$location_value = str_replace('  ',' ',$location_value);
					$location_value = ucwords($location_value);
					$search_keyword = ucwords($search_keyword);
					$title = __("Search Results for $search_keyword near $location_value", 'careerbuilder_jobs');
				// without a search keyword
				} else {
					$location_value = str_replace(',','_',$location_value);
					$location_value = explode('_', $location_value);
					if (count($location_value) > 1) {
						if (strlen($location_value[1]) == 2) {
							$location_value[1] = strtoupper($location_value[1]);
						}
						$location_value = implode(', ', $location_value);
					} else {
						$location_value = $location_value[0];
					}
					$location_value = str_replace('-',' ',$location_value);
					$location_value = ucwords($location_value);
					$location_value = str_replace('  ',' ',$location_value);
					$title = __("Jobs and Employment near $location_value", 'careerbuilder_jobs');
				}
			// company page
			} else if ( $company_value ) {
				$company_value = str_replace('-',' ',$company_value);
				$company_value = ucwords($company_value);
				// with search location and keyword
				if ( $search_location && $search_keyword ) {
					$search_keyword = ucwords($search_keyword);
					if (count($search_location) > 1) {
						$search_location = explode(' ', $search_location);
						$search_location[1] = strtoupper($search_location[1]);
						$search_location = implode(', ', $search_location);
					}
					$search_location = str_replace(',,',', ',$search_location);
					$search_location = ucwords($search_location);
					$search_location = str_replace('  ',' ',$search_location);
					$title = __("Search Results for $search_keyword in $search_location at $company_value", 'careerbuilder_jobs');
				// with just search location
				} else if ( $search_location ) {
					if (count($search_location) > 1) {
						$search_location = explode('_', $search_location);
						$search_location[1] = strtoupper($search_location[1]);
						$search_location = implode(', ', $search_location);
					}
					$search_location = str_replace(',,',', ',$search_location);
					$search_location = ucwords($search_location);
					$search_location = str_replace('  ',' ',$search_location);
					$title = __("Search Results for $search_location at $company_value", 'careerbuilder_jobs');
				// with just search keyword
				} else if ( $search_keyword ) {
					$search_keyword = ucwords($search_keyword);
					$title = __("Search Results for $search_keyword at $company_value", 'careerbuilder_jobs');
				// without search
				} else {
					$title = __("Jobs at $company_value", 'careerbuilder_jobs');
				}
			// category page
			} else if ( $category_value ) {
				// with search location and keyword
				if ( $search_location && $search_keyword ) {
					$search_keyword = ucwords($search_keyword);
					if (count($search_location) > 1) {
						$search_location = explode(' ', $search_location);
						$search_location[1] = strtoupper($search_location[1]);
						$search_location = implode(', ', $search_location);
					}
					$search_location = str_replace(',,',', ',$search_location);
					$search_location = ucwords($search_location);
					$search_location = str_replace('  ',' ',$search_location);
					$title = __("Search Results for $search_keyword in $search_location and $category_value", 'careerbuilder_jobs');
				// with just search location
				} else if ( $search_location ) {
					if (count($search_location) > 1) {
						$search_location = explode(' ', $search_location);
						$search_location[1] = strtoupper($search_location[1]);
						$search_location = implode(', ', $search_location);
					}
					$search_location = str_replace(',,',', ',$search_location);
					$search_location = ucwords($search_location);
					$search_location = str_replace('  ',' ',$search_location);
					$title = __("Search Results in $category_value near $search_location", 'careerbuilder_jobs');
				// with just search keyword
				} else if ( $search_keyword ) {
					$search_keyword = ucwords($search_keyword);
					$title = __("Search Results for $search_keyword in $category_value", 'careerbuilder_jobs');
				// without search
				} else {
					$title = __("$category_value Jobs and Employment", 'careerbuilder_jobs');
				}
			// search only
			} else if ( $search_location && $search_keyword ) {
				$search_keyword = ucwords($search_keyword);
				if (count($search_location) > 1) {
					$search_location = explode(' ', $search_location);
					$search_location[1] = strtoupper($search_location[1]);
					$search_location = implode(', ', $search_location);
				}
				$search_location = str_replace(',,',', ',$search_location);
				$search_location = ucwords($search_location);
				$search_location = str_replace('  ',' ',$search_location);
				$title = __("Search Results for $search_keyword near $search_location", 'careerbuilder_jobs');
			} else if ( $search_location ) {
				if (count($search_location) > 1) {
					$search_location = explode(' ', $search_location);
					$search_location[1] = strtoupper($search_location[1]);
					$search_location = implode(', ', $search_location);
				}
				$search_location = str_replace(',,',', ',$search_location);
				$search_location = ucwords($search_location);
				$search_location = str_replace('  ',' ',$search_location);
				$title = __("Search Results for $search_location", 'careerbuilder_jobs');
			} else if ( $search_keyword ) {
				$search_keyword = ucwords($search_keyword);
				$title = __("Search Results for $search_keyword", 'careerbuilder_jobs');
			} else {
				$title = __("Search for jobs and browse job listings", 'careerbuilder_jobs');
			}
		// title for single job page	
		} else if ( is_page("$cb_jobdetails_page") ) {
			// get job did from URL
			$job_id = get_query_var('job_did');
			$jobdid = explode("_",$job_id);
			$jobdid = $jobdid[1];
			// get details for the job did
			$jobinfo = CB_JobSearch::get_job_details( $jobdid );
			if ($jobinfo->Company && $jobinfo->Company != '') {
				$title = $jobinfo->JobTitle.__(" Job near ", 'careerbuilder_jobs').$jobinfo->LocationCity.', '.$jobinfo->LocationState.__(" at ", 'careerbuilder_jobs').$jobinfo->Company;
			} else {
				$title = $jobinfo->JobTitle.__(" Job near ", 'careerbuilder_jobs').$jobinfo->LocationCity.', '.$jobinfo->LocationState;
			}
		}
		return $title;
	}
	
	/**      
	 * Set HTML <head> content
	 * This includes meta keywords, meta descriptions, and links to Atom synchronization
	 */
	function wphead_content() {
		global $wp_query, $wp_rewrite, $posts;
		$options = get_option('careerbuilder_jobs_options');
		$cb_jobresults_page = $options['cb_jobresults_page'];
		$cb_jobdetails_page = $options['cb_jobdetails_page'];
		// head for job results page - generate keys, desc, and feed url
		if ( is_page("$cb_jobresults_page") ) {
			$bloghome = get_bloginfo('wpurl');
			$gen_value = strtolower(get_query_var('job_no_prefix'));
			$cb_permalinks = $options['cb_permalinks'];
			$search_keyword = get_query_var('keyword');
			$search_location = get_query_var('location');
			if ( !$gen_value ) {
				$location_value = strtolower(get_query_var('job_location'));
				$category_value = strtolower(get_query_var('job_category'));
				$category_value = CB_JobSearch::get_cb_category( $category_value );
				$company_value = strtolower(get_query_var('job_company'));
			} else {
				$category_value = CB_JobSearch::get_cb_category( $gen_value );
				if ( $category_value != false ) {
					$category_value = strtolower(get_query_var('job_no_prefix'));
				} else {
					$location_value = strtolower(get_query_var('job_no_prefix'));
				}
			}
			// location page
			if ( $location_value ) {
				$cb_location_prefix = $options['cb_location_prefix'];
				// if there is a prefix
				if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
					if ( $cb_permalinks == 1 ) {
						// rules for directory with prefixes
						$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_location_prefix.'/'.$location_value.'/feed';
					} else if ( $cb_permalinks == 3 ) {
						// rules for hyphenated with prefixes
						$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_location_prefix.'/'.$location_value.'/feed';
					}
				// if there is no prefix
				} else {
					if ( $cb_permalinks == 2 ) {
						// rules for directory
						$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/'.$location_value.'/feed';
					} else if ( $cb_permalinks == 4 ) {
						// rules for hyphenated
						$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'-in-'.$location_value.'/feed';
					}
				}
				// with a search keyword
				if ( $search_keyword ) {
					$search_keyword_url = urlencode(strtolower(get_query_var('keyword')));
					$url['pretty_feed'] = $url['pretty_feed'].'?keyword='.$search_keyword_url;
					$location_value = str_replace(',','_',$location_value);
					$location_value = explode('_', $location_value);
					if (count($location_value) > 1) {
						if (strlen($location_value[1]) == 2) {
							$location_value[1] = strtoupper($location_value[1]);
						}
						$location_value = implode(', ', $location_value);
					} else {
						$location_value = $location_value[0];
					}
					$location_value = str_replace('-',' ',$location_value);
					$location_value = ucwords($location_value);
					$search_keyword = ucwords($search_keyword);
					$keywords = __("$search_keyword jobs, $location_value jobs", 'careerbuilder_jobs');
					$description = __("Browse search results for $search_keyword jobs and employment near $location_value.", 'careerbuilder_jobs');
				// without a search keyword
				} else {
					$location_value = str_replace(',','_',$location_value);
					$location_value = explode('_', $location_value);
					if (count($location_value) > 1) {
						if (strlen($location_value[1]) == 2) {
							$location_value[1] = strtoupper($location_value[1]);
						}
						$location_value = implode(', ', $location_value);
					} else {
						$location_value = $location_value[0];
					}
					$location_value = str_replace('-',' ',$location_value);
					$location_value = ucwords($location_value);
					$keywords = __("$location_value jobs, $location_value employment", 'careerbuilder_jobs');
					$description = __("Browse search results for jobs and employment near $location_value.", 'careerbuilder_jobs');
				}
			// company page
			} else if ( $company_value ) {
				$cb_company_prefix = $options['cb_company_prefix'];
				// if there is a prefix
				if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
					if ( $cb_permalinks == 1 ) {
						// rules for directory with prefixes
						$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_company_prefix.'/'.$company_value.'/feed';
					} else if ( $cb_permalinks == 3 ) {
						// rules for hyphenated with prefixes
						$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_company_prefix.'/'.$company_value.'/feed';
					}
				// if there is no prefix
				} else {
					if ( $cb_permalinks == 2 ) {
						// rules for directory
						$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_company_prefix.'/'.$company_value.'/feed';
					} else if ( $cb_permalinks == 4 ) {
						// rules for hyphenated
						$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'-at-'.$company_value.'/feed';
					}
				}
				$company_value = str_replace('-',' ',$company_value);
				$company_value = ucwords($company_value);
				// with search location and keyword
				if ( $search_location && $search_keyword ) {
					$search_location_url = urlencode(strtolower(get_query_var('location')));
					$search_keyword_url = urlencode(strtolower(get_query_var('keyword')));
					$url['pretty_feed'] = $url['pretty_feed'].'?keyword='.$search_keyword_url.'&amp;location='.$search_location_url;
					$search_keyword = ucwords($search_keyword);
					if (count($search_location) > 1) {
						$search_location = explode(' ', $search_location);
						$search_location[1] = strtoupper($search_location[1]);
						$search_location = implode(', ', $search_location);
					}
					$search_location = str_replace(',,',', ',$search_location);
					$search_location = ucwords($search_location);
					$keywords = __("$company_value jobs, $search_keyword jobs at $company_value, $search_location jobs at $company_value", 'careerbuilder_jobs');
					$description = __("Search results for $search_keyword jobs in $search_location at $company_value.", 'careerbuilder_jobs');
				// with just search location
				} else if ( $search_location ) {
					$search_location_url = urlencode(strtolower(get_query_var('location')));
					$url['pretty_feed'] = $url['pretty_feed'].'?location='.$search_location_url;
					if (count($search_location) > 1) {
						$search_location = explode(' ', $search_location);
						$search_location[1] = strtoupper($search_location[1]);
						$search_location = implode(', ', $search_location);
					}
					$search_location = str_replace(',,',', ',$search_location);
					$search_location = ucwords($search_location);
					$keywords = __("$company_value jobs, $search_location jobs at $company_value", 'careerbuilder_jobs');
					$description = __("Search results for jobs in $search_location at $company_value.", 'careerbuilder_jobs');
				// with just search keyword
				} else if ( $search_keyword ) {
					$search_keyword_url = urlencode(strtolower(get_query_var('keyword')));
					$url['pretty_feed'] = $url['pretty_feed'].'?keyword='.$search_keyword_url;
					$search_keyword = ucwords($search_keyword);
					$keywords = __("$company_value jobs, $search_keyword jobs at $company_value", 'careerbuilder_jobs');
					$description = __("Search results for $search_keyword at $company_value.", 'careerbuilder_jobs');
				// without search
				} else {
					$keywords = __("$company_value jobs, $company_value employment", 'careerbuilder_jobs');
					$description = __("Browse job results for $company_value.", 'careerbuilder_jobs');
				}
			// category page
			} else if ( $category_value ) {
				$cb_category_prefix = $options['cb_category_prefix'];
				// if there is a prefix
				if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
					if ( $cb_permalinks == 1 ) {
						// rules for directory with prefixes
						$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_category_prefix.'/'.$category_value.'/feed';
					} else if ( $cb_permalinks == 3 ) {
						// rules for hyphenated with prefixes
						$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_category_prefix.'/'.$category_value.'/feed';
					}
				// if there is no prefix
				} else {
					// need to get all query vars and see what the site calls them
					if ( $cb_permalinks == 2 ) {
						// rules for directory
						$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/'.$category_value.'/feed';
					} else if ( $cb_permalinks == 4 ) {
						// rules for hyphenated
						$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'-in-'.$category_value.'/feed';
					}
				}
				// with search location and keyword
				if ( $search_location && $search_keyword ) {
					$search_location_url = urlencode(strtolower(get_query_var('location')));
					$search_keyword_url = urlencode(strtolower(get_query_var('keyword')));
					$url['pretty_feed'] = $url['pretty_feed'].'?keyword='.$search_keyword_url.'&amp;location='.$search_location_url;
					$search_keyword = ucwords($search_keyword);
					if (count($search_location) > 1) {
						$search_location = explode(' ', $search_location);
						$search_location[1] = strtoupper($search_location[1]);
						$search_location = implode(', ', $search_location);
					}
					$search_location = str_replace(',,',', ',$search_location);
					$search_location = ucwords($search_location);
					$keywords = __("$search_keyword jobs, $search_location jobs, $category_value jobs", 'careerbuilder_jobs');
					$description = __("Search results for $search_keyword jobs in the $category_value category, and located near $search_location.", 'careerbuilder_jobs');
				// with just search location
				} else if ( $search_location ) {
					$search_location_url = urlencode(strtolower(get_query_var('location')));
					$url['pretty_feed'] = $url['pretty_feed'].'?location='.$search_location_url;
					if (count($search_location) > 1) {
						$search_location = explode(' ', $search_location);
						$search_location[1] = strtoupper($search_location[1]);
						$search_location = implode(', ', $search_location);
					}
					$search_location = str_replace(',,',', ',$search_location);
					$search_location = ucwords($search_location);
					$search_location = ucwords($search_location);
					$keywords = __("$search_location jobs, $category_value jobs", 'careerbuilder_jobs');
					$description = __("Search results for jobs in the $category_value category, and located near $search_location.", 'careerbuilder_jobs');
				// with just search keyword
				} else if ( $search_keyword ) {
					$search_keyword_url = urlencode(strtolower(get_query_var('keyword')));
					$url['pretty_feed'] = $url['pretty_feed'].'?keyword='.$search_keyword_url;
					$search_keyword = ucwords($search_keyword);
					$keywords = __("$search_keyword jobs, $category_value jobs", 'careerbuilder_jobs');
					$description = __("Search results for $search_keyword jobs in the $category_value category.", 'careerbuilder_jobs');
				// without search
				} else {
					$keywords = __("$category_value jobs, $category_value employment", 'careerbuilder_jobs');
					$description = __("Search results for jobs in the $category_value category.", 'careerbuilder_jobs');
				}
			// search only
			} else if ( $search_location && $search_keyword ) {
				$search_location_url = urlencode(strtolower(get_query_var('location')));
				$search_keyword_url = urlencode(strtolower(get_query_var('keyword')));
				$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/feed/?keyword='.$search_keyword_url.'&amp;location='.$search_location_url;
				$search_keyword = ucwords($search_keyword);
				if (count($search_location) > 1) {
					$search_location = explode(' ', $search_location);
					$search_location[1] = strtoupper($search_location[1]);
					$search_location = implode(', ', $search_location);
				}
				$search_location = str_replace(',,',', ',$search_location);
				$search_location = ucwords($search_location);
				$keywords = __("$search_keyword jobs, $search_location jobs", 'careerbuilder_jobs');
				$description = __("Search results for $search_keyword jobs located near $search_location.", 'careerbuilder_jobs');
			} else if ( $search_location ) {
				$search_location_url = urlencode(strtolower(get_query_var('location')));
				$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/feed?location='.$search_location_url;
				if (count($search_location) > 1) {
					$search_location = explode(' ', $search_location);
					$search_location[1] = strtoupper($search_location[1]);
					$search_location = implode(', ', $search_location);
				}
				$search_location = str_replace(',,',', ',$search_location);
				$search_location = ucwords($search_location);
				$keywords = __("$search_location jobs, $search_location employment", 'careerbuilder_jobs');
				$description = __("Search results for jobs located near $search_location.", 'careerbuilder_jobs');
			} else if ( $search_keyword ) {
				$search_keyword_url = urlencode(strtolower(get_query_var('keyword')));
				$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/feed/?keyword='.$search_keyword_url;
				$search_keyword = ucwords($search_keyword);
				$keywords = __("$search_keyword jobs, $search_keyword employment", 'careerbuilder_jobs');
				$description = __("Search results for $search_keyword jobs.", 'careerbuilder_jobs');
			// default
			} else {
				$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/feed';
				$keywords = __("jobs, employment", 'careerbuilder_jobs');
				$description = __("", 'careerbuilder_jobs');
				$description = __("Browse jobs and employment by category or location, or search for jobs by keyword or location.", 'careerbuilder_jobs');
			}
			$keywords = str_replace('  ',' ',$keywords);
			$description = str_replace('  ',' ',$description);
			$metakeys = '<meta name="keywords" content="'.$keywords.'" />';
			$metadesc = '<meta name="description" content="'.$description.'" />';
			// create a title for the feed from the result page title and the blog name
			$title = CB_JobSearch::replace_title( $title );
			$blogname = get_bloginfo('name');
			$atomlink = '<link rel="alternate" type="application/atom+xml" href="'.$url['pretty_feed'].'/" title="'.$title.' Feed | '.$blogname.'" />';
			echo "$metakeys\n";
			echo "$metadesc\n";
			echo "$atomlink\n";
		// head for single job page	- this does not include any synchronization at this time
		} else if ( is_page("$cb_jobdetails_page") ) {
			// get job did from URL
			$job_id = get_query_var('job_did');
			$jobdid = explode("_",$job_id);
			$jobdid = $jobdid[1];
			// get details for the job did
			$jobinfo = CB_JobSearch::get_job_details( $jobdid );
			if ($jobinfo->Company && $jobinfo->Company != '') {
				$description = $jobinfo->JobTitle.__(" job near ", 'careerbuilder_jobs').$jobinfo->LocationCity.', '.$jobinfo->LocationState.__(" at ", 'careerbuilder_jobs').$jobinfo->Company;
			} else {
				$description = $jobinfo->JobTitle.__(" job near ", 'careerbuilder_jobs').$jobinfo->LocationCity.', '.$jobinfo->LocationState;
			}
			if ($jobinfo->Categories != '') {
				$keywords = $jobinfo->Categories;
			} else {
				$keywords = 'job details';
			}
			$keywords = str_replace('  ',' ',$keywords);
			$description = str_replace('  ',' ',$description);
			$metakeys = '<meta name="keywords" content="'.$keywords.'" />';
			$metadesc = '<meta name="description" content="'.$description.'" />';
			echo "$metakeys\n";
			echo "$metadesc\n";
		}
	}
	
	/**      
	 * Set up default CSS for job details and job results
	 */
	function add_cb_stylesheet() {
		$options = get_option('careerbuilder_jobs_options');
		if ( !isset($options['cb_default_css']) || $options['cb_default_css'] == 0 ) {
			$cbstyleurl = WP_PLUGIN_URL . '/careerbuilder-jobs/cb-jobs-default.css';
			$cbstylefile = WP_PLUGIN_DIR . '/careerbuilder-jobs/cb-jobs-default.css';
			if ( file_exists($cbstylefile) ) {
				wp_register_style('cbstylesheet', $cbstyleurl);
				wp_enqueue_style('cbstylesheet');
			}
		}
	}
	
	/**      
	 * Set up default JavaScript for job details and job results
	 */	
	function add_cb_javascript() {
		wp_enqueue_script('jquery');
		$options = get_option('careerbuilder_jobs_options');
		if ( !isset($options['cb_default_js']) || $options['cb_default_js'] == 0 ) {
			$cbaccordionscripturl = WP_PLUGIN_URL . '/careerbuilder-jobs/cb-jobs-accordion.js';
			$cbaccordionscriptfile = WP_PLUGIN_DIR . '/careerbuilder-jobs/cb-jobs-accordion.js';
			$cbdefaultscripturl = WP_PLUGIN_URL . '/careerbuilder-jobs/cb-jobs-default.js';
			$cbdefaultscriptfile = WP_PLUGIN_DIR . '/careerbuilder-jobs/cb-jobs-default.js';
			if ( !is_admin() ) {
				if ( file_exists($cbaccordionscriptfile) ) {
	  			wp_enqueue_script('cbaccordionscript', $cbaccordionscripturl, array('jquery'));
  			}
   			if ( file_exists($cbdefaultscriptfile) ) {
	  			wp_enqueue_script('cbdefaultscript', $cbdefaultscripturl, array('jquery', 'cbaccordionscript'));
  			}
			}
		}
		if ( isset($options['cb_allow_tooltips']) && $options['cb_allow_tooltips'] == 1 ) {
			$cbtoolscripturl = WP_PLUGIN_URL . '/careerbuilder-jobs/jquery.tools.js';
			$cbtoolscriptfile = WP_PLUGIN_DIR . '/careerbuilder-jobs/jquery.tools.js';
			$cbscripturl = WP_PLUGIN_URL . '/careerbuilder-jobs/cb-jobs-tooltips.js';
			$cbscriptfile = WP_PLUGIN_DIR . '/careerbuilder-jobs/cb-jobs-tooltips.js';
			if ( !is_admin() ) {
				if ( file_exists($cbtoolscriptfile) ) {
	  			wp_enqueue_script('cbtoolscript', $cbtoolscripturl, array('jquery'));
  			}
  			if ( file_exists($cbscriptfile) ) {
	  			wp_enqueue_script('cbscript', $cbscripturl, array('jquery'));
  			}
			}
		}
	}
	
	/**
	 * CareerBuilder job results for RSS feed. Calls specific functions based on URL.
	 */
	function write_job_feed() {
		global $wp_query, $wp_rewrite, $posts;
		$options = get_option('careerbuilder_jobs_options');
		$cb_developer_key = $options['cb_developer_key'];
		$cb_siteid = 'wpp_'.$cb_developer_key;
		$cb_cobrand_code = $options['cb_cobrand_code'];
		$cb_jobs_perfeed = $options['cb_jobs_perfeed'];
		$cb_jobs_postedwithin = $options['cb_jobs_postedwithin'];
		$gen_value = strtolower(get_query_var('job_no_prefix'));
		$search_location = get_query_var('location');
		$search_keyword = get_query_var('keyword');
		if ( !$gen_value ) {
			$location_value = strtolower(get_query_var('job_location'));
			$category_value = strtolower(get_query_var('job_category'));
			$company_value = strtolower(get_query_var('job_company'));
		} else {
			$category_value = CB_JobSearch::get_cb_category( $gen_value );
			if ( $category_value != false ) {
				$category_value = strtolower(get_query_var('job_no_prefix'));
			} else {
				$location_value = strtolower(get_query_var('job_no_prefix'));
			}
		}
		$feed = get_query_var( 'feed' );
		$feed_excerpt = get_option( 'rss_use_excerpt' );
		$blog_charset = get_option( 'blog_charset' );
		$blogtitle = get_bloginfo( 'name' );
		$title = CB_JobSearch::replace_title( $blogtitle );
		$subtitle = 'Your job search feed';
		$search_location = urlencode(strtolower(get_query_var('location')));
		$search_keyword = urlencode(strtolower(get_query_var('keyword')));

		$bloghome = get_bloginfo('wpurl');
		$cb_jobresults_page = $options['cb_jobresults_page'];
		$cb_jobdetails_page = $options['cb_jobdetails_page'];
		$url['details_root'] = $bloghome.'/'.$cb_jobdetails_page;
		
		$cb_permalinks = $options['cb_permalinks'];
		// location feed
		if ( $location_value ) {
			$cb_location_prefix = $options['cb_location_prefix'];
			$url['feed_root'] = $bloghome.'/?page=jobs&amp;job_location='.$location_value.'&amp;feed=jobs';
			// if there is a prefix
			if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
				if ( $cb_permalinks == 1 ) {
					// rules for directory with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_location_prefix.'/'.$location_value;
					$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_location_prefix.'/'.$location_value.'/feed';
				} else if ( $cb_permalinks == 3 ) {
					// rules for hyphenated with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_location_prefix.'/'.$location_value;
					$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_location_prefix.'/'.$location_value.'/feed';
				}
			// if there is no prefix
			} else {
				if ( $cb_permalinks == 2 ) {
					// rules for directory
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$location_value;
					$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/'.$location_value.'/feed';
				} else if ( $cb_permalinks == 4 ) {
					// rules for hyphenated
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-in-'.$location_value;
					$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'-in-'.$location_value.'/feed';
				}
			}
			$jobs = CB_JobSearch::get_jobs_by_location( $cb_developer_key,$cb_siteid,$cb_cobrand_code,$location_value,$search_keyword,$page_num,$cb_jobs_perfeed,$cb_jobs_postedwithin,$url,true );
		// company feed
		} else if ( $company_value ) {
			$cb_company_prefix = $options['cb_company_prefix'];
			$url['feed_root'] = $bloghome.'/?page=jobs&amp;job_company='.$company_value.'&amp;feed=jobs';
			// if there is a prefix
			if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
				if ( $cb_permalinks == 1 ) {
					// rules for directory with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_company_prefix.'/'.$company_value;
					$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_company_prefix.'/'.$company_value.'/feed';
				} else if ( $cb_permalinks == 3 ) {
					// rules for hyphenated with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_company_prefix.'/'.$company_value;
					$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_company_prefix.'/'.$company_value.'/feed';
				}
			// if there is no prefix
			} else {
				if ( $cb_permalinks == 2 ) {
					// rules for directory
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_company_prefix.'/'.$company_value;
					$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_company_prefix.'/'.$company_value.'/feed';
				} else if ( $cb_permalinks == 4 ) {
					// rules for hyphenated
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-at-'.$company_value;
					$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'-at-'.$company_value.'/feed';
				}
			}
			$jobs = CB_JobSearch::get_jobs_by_company( $cb_developer_key,$cb_siteid,$cb_cobrand_code,$company_value,$search_location,$search_keyword,$page_num,$cb_jobs_perfeed,$cb_jobs_postedwithin,$url,true);
		// category feed
		} else if ( $category_value ) {
			$cb_category_prefix = $options['cb_category_prefix'];
			$url['feed_root'] = $bloghome.'/?page=jobs&amp;job_category='.$category_value.'&amp;feed=jobs';
			// if there is a prefix
			if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
				if ( $cb_permalinks == 1 ) {
					// rules for directory with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_category_prefix.'/'.$category_value;
					$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_category_prefix.'/'.$category_value.'/feed';
				} else if ( $cb_permalinks == 3 ) {
					// rules for hyphenated with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_category_prefix.'/'.$category_value;
					$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_category_prefix.'/'.$category_value.'/feed';
				}
			// if there is no prefix
			} else {
				// need to get all query vars and see what the site calls them
				if ( $cb_permalinks == 2 ) {
					// rules for directory
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$category_value;
					$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/'.$category_value.'/feed';
				} else if ( $cb_permalinks == 4 ) {
					// rules for hyphenated
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-in-'.$category_value;
					$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'-in-'.$category_value.'/feed';
				}
			}
			$jobs = CB_JobSearch::get_jobs_by_category( $cb_developer_key,$cb_siteid,$cb_cobrand_code,$category_value,$search_location,$search_keyword,$page_num,$cb_jobs_perfeed,$cb_jobs_postedwithin,$url,true );
		// search only feed
		} else if ( $search_location || $search_keyword ) {
			$url['results_root'] = $bloghome.'/'.$cb_jobresults_page;
			$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/feed/?keyword='.$search_keyword.'&amp;location='.$search_location;
			$url['feed_root'] = $bloghome.'/?page=jobs&amp;keyword='.$search_keyword.'&amp;location='.$search_location.'&amp;feed=jobs';
			$jobs = CB_JobSearch::get_jobs_by_search( $cb_developer_key,$cb_siteid,$cb_cobrand_code,$search_location,$search_keyword,$page_num,$cb_jobs_perfeed,$cb_jobs_postedwithin,$url,true );
		} else {
			$url['results_root'] = $bloghome.'/'.$cb_jobresults_page;
			$url['pretty_feed'] = $bloghome.'/'.$cb_jobresults_page.'/feed';
			$url['feed_root'] = $bloghome.'/?page=jobs&amp;feed=jobs';
			$jobs = CB_JobSearch::get_jobs_by_search( $cb_developer_key,$cb_siteid,$cb_cobrand_code,'','',$page_num,$cb_jobs_perfeed,$cb_jobs_postedwithin,$url,true );
		}
		if ($jobs) {
			/** 
			 * This file displays the feed for Job Results.
			 * Here we retrieve a couple of fields for the most recent job's details, in order to indicate the feed's last update date.
			 */
			$newestjob = $jobs['collection'][0];
			$jobdid = $newestjob->DID;
			$jobdetails = CB_JobSearch::get_job_details( $jobdid );
			$modified = $jobdetails->ModifiedDate;
			$modified_feed = mysql2date( 'Y-m-d\TH:i:s\Z', $modified, true );
			include( 'careerbuilder-job-results-atom.php' );
		}	
	}

	/**
	 * CareerBuilder job results for display. Calls specific functions based on URL.
	 */
	function show_job_results() {
		global $wp_query, $wp_rewrite, $posts;
		// html layout for results
		include('careerbuilder-jobs-formatting.php');
		$options = get_option('careerbuilder_jobs_options');
		$cb_developer_key = $this->cb_developer_key;
		$cb_siteid = 'wpp_'.$cb_developer_key;
		$cb_cobrand_code = $options['cb_cobrand_code'];
		$cb_jobs_perpage = $options['cb_jobs_perpage'];
		$cb_jobs_postedwithin = $options['cb_jobs_postedwithin'];
		$cb_remove_searchform = $options['cb_default_searchform'];
		$gen_value = strtolower(get_query_var('job_no_prefix'));
		$search_location = get_query_var('location');
		$search_keyword = get_query_var('keyword');
		if ( !$gen_value ) {
			$location_value = strtolower(get_query_var('job_location'));
			$category_value = strtolower(get_query_var('job_category'));
			$company_value = strtolower(get_query_var('job_company'));
		} else {
			$category_value = CB_JobSearch::get_cb_category( $gen_value );
			if ( $category_value != false ) {
				$category_value = strtolower(get_query_var('job_no_prefix'));
			} else {
				$location_value = strtolower(get_query_var('job_no_prefix'));
			}
		}
		$page_num = get_query_var('page');
		$search_location = urlencode(strtolower(get_query_var('location')));
		$search_keyword = urlencode(strtolower(get_query_var('keyword')));

		$bloghome = get_bloginfo('wpurl');
		$cb_jobresults_page = $options['cb_jobresults_page'];
		$cb_jobdetails_page = $options['cb_jobdetails_page'];
		$url['details_root'] = $bloghome.'/'.$cb_jobdetails_page;

		if ( $search_location && $search_keyword ) {
			$url['searchquery'] = "?keyword=$search_keyword&amp;location=$search_location";
			//setcookie("search_location", "$search_location", time()+3600, COOKIEPATH, COOKIE_DOMAIN);
			//setcookie("search_keyword", "$search_keyword", time()+3600, COOKIEPATH, COOKIE_DOMAIN);
		} else if ( $search_location ) {
			//setcookie("search_location", "$search_location", time()+3600, COOKIEPATH, COOKIE_DOMAIN);
			$url['searchquery'] = "?location=$search_location";
		} else if ( $search_keyword ) {
			//setcookie("search_keyword", "$search_keyword", time()+3600, COOKIEPATH, COOKIE_DOMAIN);
			$url['searchquery'] = "?keyword=$search_keyword";
		} else {
			$url['searchquery'] = '';
		}
		$cb_permalinks = $options['cb_permalinks'];
		if ( $location_value ) {
			$cb_location_prefix = $options['cb_location_prefix'];	
			// if there is a prefix
			if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
				if ( $cb_permalinks == 1 ) {
					// rules for directory with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_location_prefix.'/'.$location_value;
				} else if ( $cb_permalinks == 3 ) {
					// rules for hyphenated with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_location_prefix.'/'.$location_value;
				}
			// if there is no prefix
			} else {
				if ( $cb_permalinks == 2 ) {
					// rules for directory
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$location_value;	
				} else if ( $cb_permalinks == 4 ) {
					// rules for hyphenated
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-in-'.$location_value;
				}
			}
			$jobs = CB_JobSearch::get_jobs_by_location( $cb_developer_key,$cb_siteid,$cb_cobrand_code,$location_value,$search_keyword,$page_num,$cb_jobs_perpage,$cb_jobs_postedwithin,$url,false );
		} else if ( $company_value ) {
			$cb_company_prefix = $options['cb_company_prefix'];
			// if there is a prefix
			if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
				if ( $cb_permalinks == 1 ) {
					// rules for directory with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_company_prefix.'/'.$company_value;
				} else if ( $cb_permalinks == 3 ) {
					// rules for hyphenated with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_company_prefix.'/'.$company_value;
				}
			// if there is no prefix
			} else {
				if ( $cb_permalinks == 2 ) {
					// rules for directory
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_company_prefix.'/'.$company_value;
				} else if ( $cb_permalinks == 4 ) {
					// rules for hyphenated
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-at-'.$company_value;
				}
			}
			$jobs = CB_JobSearch::get_jobs_by_company( $cb_developer_key,$cb_siteid,$cb_cobrand_code,$company_value,$search_location,$search_keyword,$page_num,$cb_jobs_perpage,$cb_jobs_postedwithin,$url,false ) ;
		} else if ( $category_value ) {
			$cb_category_prefix = $options['cb_category_prefix'];
			// if there is a prefix
			if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
				if ( $cb_permalinks == 1 ) {
					// rules for directory with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_category_prefix.'/'.$category_value;					
				} else if ( $cb_permalinks == 3 ) {
					// rules for hyphenated with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_category_prefix.'/'.$category_value;
				}
			// if there is no prefix
			} else {
				// need to get all query vars and see what the site calls them
				if ( $cb_permalinks == 2 ) {
					// rules for directory
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$category_value;
				} else if ( $cb_permalinks == 4 ) {
					// rules for hyphenated
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-in-'.$category_value;
				}
			}
			$jobs = CB_JobSearch::get_jobs_by_category( $cb_developer_key,$cb_siteid,$cb_cobrand_code,$category_value,$search_location,$search_keyword,$page_num,$cb_jobs_perpage,$cb_jobs_postedwithin,$url,false );
		} else if ( $search_location || $search_keyword ) {
			$url['results_root'] = $bloghome.'/'.$cb_jobresults_page;
			$jobs = CB_JobSearch::get_jobs_by_search( $cb_developer_key,$cb_siteid,$cb_cobrand_code,$search_location,$search_keyword,$page_num,$cb_jobs_perpage,$cb_jobs_postedwithin,$url,false );
		}
		if ($jobs) {
			/**
			* This file displays the content for Job Results. If you keep the default plugin settings, we'll include our CSS for this content, though you can write your own and remove ours with the plugin settings.
			 * You can also add a careerbuilder-job-details.php to your own theme, and completely reformat the way this content is included. If you have this file, we'll use it instead of ours.
			*/
			if ($cb_remove_searchform != 1) {
				$searchform = CB_JobSearch::default_jobsearch_form( 'cb_jobs_results' );
			}
			if (!@fopen($this->theme_dir.'/'.'careerbuilder-job-results.php', 'r')) {
				include( 'careerbuilder-job-results.php' );
			} else {
				// if the theme has a details page, use it
				include( $this->theme_path.'/'.'careerbuilder-job-results.php' );
			}
			
			
		} else {
			// show this if we are on the jobs landing page
			$cb_category_prefix = $options['cb_category_prefix'];
			$cb_location_prefix = $options['cb_location_prefix'];
			$cb_permalinks = $options['cb_permalinks'];
			if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
				if ( $cb_permalinks == 1 ) {
					// rules for directory with prefixes
					$url['catroot'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_category_prefix.'/';
					$url['locroot'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_location_prefix.'/';
				} else if ( $cb_permalinks == 3 ) {
					// rules for hyphenated with prefixes
					$url['catroot'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_category_prefix.'/';
					$url['locroot'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_location_prefix.'/';
				}
			// if there is no prefix
			} else {
				// need to get all query vars and see what the site calls them
				if ( $cb_permalinks == 2 ) {
					// rules for directory
					$url['catroot'] = $bloghome.'/'.$cb_jobresults_page.'/';
					$url['locroot'] = $bloghome.'/'.$cb_jobresults_page.'/';
				} else if ( $cb_permalinks == 4 ) {
					// rules for hyphenated
					$url['catroot'] = $bloghome.'/'.$cb_jobresults_page.'-in-';
					$url['locroot'] = $bloghome.'/'.$cb_jobresults_page.'-in-';
				}
			}
			$categories = CB_JobSearch::get_cb_categories();
			$locations = CB_JobSearch::get_cb_locations( '' );
			/**
			* This file displays the content for the /jobs page. If you include a file in your theme called careerbuilder-jobs-home.php, we'll use that.
			*/
			if (!@fopen($this->theme_dir.'/'.'careerbuilder-jobs-home.php', 'r')) {
				include( 'careerbuilder-jobs-home.php' );
			} else {
				// if the theme has a home page, use it
				include( $this->theme_path.'/'.'careerbuilder-jobs-home.php' );
			}
			if ($cb_remove_searchform != 1) {
				$searchform = CB_JobSearch::default_jobsearch_form( 'cb_jobs_home' );
			}
		}
	}
	
	/**
	 * @return CareerBuilder job results by GET queries sent from search form.
	 * This is called by the overall result display function
	 */
	function get_jobs_by_search( $cb_developer_key,$cb_siteid,$cb_cobrand_code,$search_location,$search_keyword,$page_num,$cb_jobs_perpage,$cb_jobs_postedwithin,$url,$feed ) {
		global $wp_query, $wp_rewrite, $posts;
		if ( $page_num != '' ) {
			$page_num = $page_num;
		} else {
			$page_num = 1;
		}
		$joburl = "http://api.careerbuilder.com/v2/jobsearch/?DeveloperKey=".$cb_developer_key."&location=".$search_location."&keywords=".$search_keyword."&PageNumber=".$page_num."&PostedWithin=$cb_jobs_postedwithin&PerPage=$cb_jobs_perpage&SiteID=$cb_siteid&CoBrand=$cb_cobrand_code&ExcludeNational=True";
		try {
			$xml = simplexml_load_file( $joburl );
		} catch( Exception $e ) {
			print_r( $e );
		}
		if ( $xml ) {
			$jobs_collection = Array();
			$current_item = 0;
			$total = (int)$xml->TotalCount;
			$pages = (int)$xml->TotalPages;
			foreach ( $xml->Results->JobSearchResult as $result ) {
				$slug = sanitize_title( $result->JobTitle );
				$url_id = $slug.'_'.$result->DID;
				$result->job_url = $url['details_root'].'/'.$url_id.'/';
				$jobs_collection[$current_item] = $result;
				$current_item ++;
			}
			$firstnum = number_format_i18n( (int)$xml->FirstItemIndex );
	  	$lastnum = (int)$xml->LastItemIndex;
	  	if ( $total > $lastnum ) {
	  		$lastnum = number_format_i18n( $lastnum );
	  	} else {
	  		$lastnum = $total;
	  	}
			$jobs = array();
			$jobs['range'] = "$firstnum - $lastnum";
			$jobs['pages'] = $pages;
			$jobs['machine_total'] = $total;
			$jobs['total'] = number_format_i18n( $total, $decimals = null );
			if ($search_keyword != '' && $search_location != '') {
				if (count($search_location) > 1) {
					$search_location = explode('%2C+', $search_location);
					if (strlen($search_location[1]) == 2) {
						$search_location[1] = strtoupper($search_location[1]);
					}
					$search_location = implode(', ', $search_location);
				}
				$search_location = str_replace('%2C+',', ',$search_location);
				$search_location = str_replace('+',' ',$search_location);
				$search_location = ucwords($search_location);		
				$jobs['heading'] = __('Displaying results ', 'careerbuilder_jobs').$jobs['range'].__(' of ', 'careerbuilder_jobs').$jobs['total'].__(" for ", 'careerbuilder_jobs').'&ldquo;'.$search_keyword.'&rdquo;'.__(" near ", 'careerbuilder_jobs').$search_location;
			} else if ($search_keyword != '') {
				$jobs['heading'] = __('Displaying results ', 'careerbuilder_jobs').$jobs['range'].__(' of ', 'careerbuilder_jobs').$jobs['total'].__(" for ", 'careerbuilder_jobs').'&ldquo;'.$search_keyword.'&rdquo;';
			} else if ($search_location != '') {
				if (count($search_location) > 1) {
					$search_location = explode('%2C+', $search_location);
					$search_location[1] = strtoupper($search_location[1]);
					$search_location = implode(', ', $search_location);
				}
				$search_location = str_replace('%2C+',', ',$search_location);
				$search_location = str_replace('+',' ',$search_location);
				$search_location = ucwords($search_location);			
				$jobs['heading'] = __('Displaying results ', 'careerbuilder_jobs').$jobs['range'].__(' of ', 'careerbuilder_jobs').$jobs['total'].__(" near ", 'careerbuilder_jobs').$search_location;
			} else {
				$jobs['heading'] = __('Displaying results ', 'careerbuilder_jobs').$jobs['range'].__(' of ', 'careerbuilder_jobs').$jobs['total'];
			}
			$jobs['collection'] = $jobs_collection;
			if ($feed != 1) {
				$jobs['pagination'] = cb_pagination($page_num,$pages,$cb_jobs_perpage,$url);
			}
			return $jobs;
		} else {
		}
	}
	
	/**
	 * @return CareerBuilder job results by location values in URL
	 * This is called by the overall result display function
	 */
	function get_jobs_by_location( $cb_developer_key,$cb_siteid,$cb_cobrand_code,$location_value,$search_keyword,$page_num,$cb_jobs_perpage,$cb_jobs_postedwithin,$url,$feed ) {
		global $wp_query, $wp_rewrite, $posts;
		if ( $page_num != '' ) {
			$page_num = $page_num;
		} else {
			$page_num = 1;
		}		
		$location_string = str_replace('-', '+', $location_value);
		$location_string = str_replace('_','+',$location_string);
		$joburl = "http://api.careerbuilder.com/v2/jobsearch/?DeveloperKey=".$cb_developer_key."&location=".$location_string."&keywords=".$search_keyword."&PageNumber=".$page_num."&PostedWithin=$cb_jobs_postedwithin&PerPage=$cb_jobs_perpage&SiteID=$cb_siteid&CoBrand=$cb_cobrand_code&ExcludeNational=True";
		try {
			$xml = simplexml_load_file( $joburl );
		} catch( Exception $e ) {
			print_r( $e );
		}
		if ( $xml ) {
			$jobs_collection = Array();
			$current_item = 0;
			$total = (int)$xml->TotalCount;
			$pages = (int)$xml->TotalPages;
			foreach ( $xml->Results->JobSearchResult as $result ) {
				$slug = sanitize_title( $result->JobTitle );
				$url_id = $slug.'_'.$result->DID;
				$result->job_url = $url['details_root'].'/'.$url_id.'/';
				$jobs_collection[$current_item] = $result;
				$current_item ++;
			}
			$firstnum = number_format_i18n( (int)$xml->FirstItemIndex );
	  	$lastnum = (int)$xml->LastItemIndex;
	  	if ( $total > $lastnum ) {
	  		$lastnum = number_format_i18n( $lastnum );
	  	} else {
	  		$lastnum = $total;
	  	}
			$range = "$firstnum - $lastnum";
			$location_value = str_replace(',','_',$location_value);
			$location_value = explode('_', $location_value);
			if (count($location_value) > 1) {
				if (strlen($location_value[1]) == 2) {
					$location_value[1] = strtoupper($location_value[1]);
				}
				$location_value = implode(', ', $location_value);
			} else {
				$location_value = $location_value[0];
			}
			$location_value = str_replace('-',' ',$location_value);
			$location_value = ucwords($location_value);
			$jobs = array();
			$jobs['pages'] = $pages;
			$jobs['machine_total'] = $total;
			$jobs['total'] = number_format_i18n( $total, $decimals = null );
			$jobs['range'] = $range;
			if ($search_keyword != '') {
				$search_keyword = str_replace('+',' ',$search_keyword);
				$jobs['heading'] = __('Displaying ', 'careerbuilder_jobs').$jobs['range'].__(' of ', 'careerbuilder_jobs').$jobs['total'].__(" job results for ", 'careerbuilder_jobs').'&ldquo;'.$search_keyword.'&rdquo;'.__(" near ", 'careerbuilder_jobs').ucwords($location_value);
			} else {
				$jobs['heading'] = __('Browse and search jobs near ', 'careerbuilder_jobs').ucwords($location_value);
				$jobs['heading2'] = __('Currently showing results ', 'careerbuilder_jobs').$jobs['range'].__(' of ', 'careerbuilder_jobs').$lastnum = $jobs['total'].__(' jobs', 'careerbuilder_jobs');
			}
			$jobs['collection'] = $jobs_collection;
			if ($feed != 1) {
				$jobs['pagination'] = cb_pagination($page_num,$pages,$cb_jobs_perpage,$url);
			}
			return $jobs;
		} else {
		}
	}
	
	/**
	 * @return CareerBuilder job results by category values in URL
	 * This is called by the overall result display function
	 */
	function get_jobs_by_category( $cb_developer_key,$cb_siteid,$cb_cobrand_code,$category_value,$search_location,$search_keyword,$page_num,$cb_jobs_perpage,$cb_jobs_postedwithin,$url,$feed ) {
		global $wp_query, $wp_rewrite, $posts;
		if ( $page_num != '' ) {
			$page_num = $page_num;
		} else {
			$page_num = 1;
		}
		$category_value = CB_JobSearch::get_cb_category( $category_value );
		if ( $category_value != false ) {
			$search_category = urlencode( $category_value );
 			$joburl = "http://api.careerbuilder.com/v2/jobsearch/?DeveloperKey=".$cb_developer_key."&category=".$search_category."&location=".$search_location."&keywords=".$search_keyword."&PageNumber=".$page_num."&PostedWithin=$cb_jobs_postedwithin&PerPage=$cb_jobs_perpage&SiteID=$cb_siteid&CoBrand=$cb_cobrand_code&ExcludeNational=True";
			try {
				$xml = simplexml_load_file( $joburl );
			} catch( Exception $e ) {
				print_r( $e );
			}
			if ( $xml ) {
				$jobs_collection = Array();
				$current_item = 0;
				$total = (int)$xml->TotalCount;
				$pages = (int)$xml->TotalPages;
				foreach ( $xml->Results->JobSearchResult as $result ) {
					$slug = sanitize_title( $result->JobTitle );
					$url_id = $slug.'_'.$result->DID;
					$result->job_url = $url['details_root'].'/'.$url_id.'/';
					$jobs_collection[$current_item] = $result;
					$current_item ++;
				}
				$firstnum = number_format_i18n( (int)$xml->FirstItemIndex );
	  		$lastnum = (int)$xml->LastItemIndex;
		  	if ( $total > $lastnum ) {
		  		$lastnum = number_format_i18n( $lastnum );
		  	} else {
		  		$lastnum = $total;
		  	}
				$range = "$firstnum - $lastnum";
				$jobs = array();
				$jobs['pages'] = $pages;
				$jobs['machine_total'] = $total;
				$jobs['total'] = number_format_i18n( $total, $decimals = null );
				$jobs['range'] = $range;
				if ($search_keyword != '' && $search_location != '') {
					$search_keyword = str_replace('+',' ',$search_keyword);
					if (count($search_location) > 1) {
						$search_location = explode('%2C+', $search_location);
						$search_location[1] = strtoupper($search_location[1]);
						$search_location = implode(', ', $search_location);
					}
					$search_location = str_replace('%2C+',', ',$search_location);
					$search_location = str_replace('+',' ',$search_location);
					$search_location = ucwords($search_location);				
					$jobs['heading'] = __('Displaying ', 'careerbuilder_jobs').$jobs['range'].__(' of ', 'careerbuilder_jobs').$jobs['total'].' '.ucwords($category_value).__(" job results for ", 'careerbuilder_jobs').'&ldquo;'.$search_keyword.'&rdquo;'.__(" near ", 'careerbuilder_jobs').$search_location;
				} else if ($search_keyword != '') {
					$search_keyword = str_replace('+',' ',$search_keyword);
					$jobs['heading'] = __('Displaying ', 'careerbuilder_jobs').$jobs['range'].__(' of ', 'careerbuilder_jobs').$jobs['total'].' '.ucwords($category_value).__(" job results for ", 'careerbuilder_jobs').'&ldquo;'.$search_keyword.'&rdquo;';
				} else if ($search_location != '') {
					if (count($search_location) > 1) {
						$search_location = explode('%2C+', $search_location);
						$search_location[1] = strtoupper($search_location[1]);
						$search_location = implode(', ', $search_location);
					}
					$search_location = str_replace('%2C+',', ',$search_location);
					$search_location = str_replace('+',' ',$search_location);
					$search_location = ucwords($search_location);
					$jobs['heading'] = __('Displaying ', 'careerbuilder_jobs').$jobs['range'].__(' of ', 'careerbuilder_jobs').$jobs['total'].' '.ucwords($category_value).__(" job results near ", 'careerbuilder_jobs').$search_location;
				} else {
					$jobs['heading'] = __('Browse and search jobs in the ', 'careerbuilder_jobs').$category_value.__(" category", 'careerbuilder_jobs');
					$jobs['heading2'] = __('Currently showing results ', 'careerbuilder_jobs').$jobs['range'].__(' of ', 'careerbuilder_jobs').$lastnum = $jobs['total'].__(' jobs', 'careerbuilder_jobs');
				}
				$jobs['collection'] = $jobs_collection;
				if ($feed != 1) {
					$jobs['pagination'] = cb_pagination($page_num,$pages,$cb_jobs_perpage,$url);
				}
				return $jobs;
			}
		} else {
			$wp_query->is_404=true;
		}
	}
	
	/**
	 * @return CareerBuilder job results by company values in URL
	 * This is called by the overall result display function
	 */
	function get_jobs_by_company( $cb_developer_key,$cb_siteid,$cb_cobrand_code,$company_value,$search_location,$search_keyword,$page_num,$cb_jobs_perpage,$cb_jobs_postedwithin,$url,$feed ) {
		global $wp_query, $wp_rewrite, $posts;
		if ( $page_num != '' ) {
			$page_num = $page_num;
		} else {
			$page_num = 1;
		}
		$company_string = urlencode($company_value);
		$joburl = "http://api.careerbuilder.com/v2/jobsearch/?DeveloperKey=".$cb_developer_key."&CompanyName=".$company_string."&location=".$search_location."&keywords=".$search_keyword."&PageNumber=".$page_num."&PostedWithin=$cb_jobs_postedwithin&PerPage=$cb_jobs_perpage&SiteID=$cb_siteid&CoBrand=$cb_cobrand_code&ExcludeNational=True";
		try {
			$xml = simplexml_load_file( $joburl );
		} catch( Exception $e ) {
			print_r( $e );
		}
		if ( $xml ) {
			$jobs_collection = Array();
			$current_item = 0;
			$total = (int)$xml->TotalCount;
			$pages = (int)$xml->TotalPages;
			foreach ( $xml->Results->JobSearchResult as $result ) {
				$slug = sanitize_title( $result->JobTitle );
				$url_id = $slug.'_'.$result->DID;
				$result->job_url = $url['details_root'].'/'.$url_id.'/';
				$jobs_collection[$current_item] = $result;
				$current_item ++;
			}
			$firstnum = number_format_i18n( (int)$xml->FirstItemIndex );
			$lastnum = (int)$xml->LastItemIndex;
	  	if ( $total > $lastnum ) {
	  		$lastnum = number_format_i18n( $lastnum );
	  	} else {
	  		$lastnum = $total;
	  	}
	  	$company_value = str_replace('-',' ',$company_value);
			$range = "$firstnum - $lastnum";
			$jobs = array();
			$jobs['pages'] = $pages;
			$jobs['machine_total'] = $total;
			$jobs['total'] = number_format_i18n( $total, $decimals = null );
			$jobs['range'] = $range;
			if ($search_keyword != '' && $search_location != '') {
				$search_keyword = str_replace('+',' ',$search_keyword);
				if (count($search_location) > 1) {
					$search_location = explode('%2C+', $search_location);
					$search_location[1] = strtoupper($search_location[1]);
					$search_location = implode(', ', $search_location);
				}
				$search_location = str_replace('%2C+',', ',$search_location);
				$search_location = str_replace('+',' ',$search_location);
				$search_location = ucwords($search_location);		
				$jobs['heading'] = __('Displaying ', 'careerbuilder_jobs').$jobs['range'].__(' of ', 'careerbuilder_jobs').$jobs['total'].' '.ucwords($category_value).__(" job results for ", 'careerbuilder_jobs').'&ldquo;'.$search_keyword.'&rdquo;'.__(" at ", 'careerbuilder_jobs').ucwords($company_value).__(" near ", 'careerbuilder_jobs').$search_location;
			} else if ($search_keyword != '') {
				$search_keyword = str_replace('+',' ',$search_keyword);
				$jobs['heading'] = __('Displaying ', 'careerbuilder_jobs').$jobs['range'].__(' of ', 'careerbuilder_jobs').$jobs['total'].' '.ucwords($category_value).__(" job results for ", 'careerbuilder_jobs').'&ldquo;'.$search_keyword.'&rdquo;'.__(" at ", 'careerbuilder_jobs').ucwords($company_value);
			} else if ($search_location != '') {
				if (count($search_location) > 1) {
					$search_location = explode('%2C+', $search_location);
					$search_location[1] = strtoupper($search_location[1]);
					$search_location = implode(', ', $search_location);
				}
				$search_location = str_replace('%2C+',', ',$search_location);
				$search_location = str_replace('+',' ',$search_location);
				$search_location = ucwords($search_location);
				$jobs['heading'] = __('Displaying ', 'careerbuilder_jobs').$jobs['range'].__(' of ', 'careerbuilder_jobs').$jobs['total'].' '.ucwords($category_value).__(" job results at ", 'careerbuilder_jobs').ucwords($company_value).__(" near ", 'careerbuilder_jobs').$search_location;
			} else {
				$jobs['heading'] = __('Browse and search ', 'careerbuilder_jobs').__(" jobs", 'careerbuilder_jobs').__(" at ", 'careerbuilder_jobs').ucwords($company_value);
				$jobs['heading2'] = __('Currently showing results ', 'careerbuilder_jobs').$jobs['range'].__(' of ', 'careerbuilder_jobs').$lastnum = $jobs['total'].__(' jobs', 'careerbuilder_jobs');
			}
			$jobs['collection'] = $jobs_collection;
			if ($feed != 1) {
				$jobs['pagination'] = cb_pagination($page_num,$pages,$cb_jobs_perpage,$url);
			}
			return $jobs;
		} else {
		}
	}
	
	/**
	 * @return CareerBuilder job recommendations for a given job.
	 * Job recommendations are returned and ordered by relevancy that is assigned by our patented recommendation engine.
	 * They are currently displayed on the job details page if the plugin user selects that option.
	 */
	 function get_job_recommendations( $cb_developer_key,$jobdid ) {
		global $wp_query, $wp_rewrite, $posts;
		// formatting
		include('careerbuilder-jobs-formatting.php');
		$options = get_option('careerbuilder_jobs_options');
		$cb_developer_key = $this->cb_developer_key;
		$cb_siteid = 'wpp_'.$cb_developer_key;
		$cb_cobrand_code = $options['cb_cobrand_code'];
		$minquality = 0;
		$joburl = 'http://api.careerbuilder.com/v2/recommendations/forjob/?DeveloperKey='.$cb_developer_key.'&JobDID='.$jobdid.'&CountLimit=5'.'&MinQualityLimit='.$minquality.'&SiteID='.$cb_siteid.'&CoBrand='.$cb_cobrand_code.'';
		try {
			$xml = simplexml_load_file( $joburl );
		} catch( Exception $e ) {
			print_r( $e );
		}
		if ( $xml ) {
			$jobs = array();
			$current_item = 0;
			$bloghome = get_bloginfo('wpurl');
			$cb_jobdetails_page = $options['cb_jobdetails_page'];
			foreach ( $xml->RecommendJobResults->RecommendJobResult as $result ) {
				$slug = sanitize_title( $result->Title );
				$url_id = $slug.'_'.$result->JobDID;
				$result->job_url = $bloghome.'/'.$cb_jobdetails_page.'/'.$url_id.'/';
				$jobs_collection[$current_item] = $result;
				$current_item ++;
			}
			$jobs = $jobs_collection;
			return $jobs;
		} else {
		}
	}
	
	/**
	 * Basic job search form - usable by itself, or within a widget.
	 */
	function default_jobsearch_form( $page ) {
		if ($page) {
			$page = " $page";
		}
		$options = get_option('careerbuilder_jobs_options');
		$bloghome = get_bloginfo('wpurl');
		$cb_jobresults_page = $options['cb_jobresults_page'];
		$gen_value = strtolower(get_query_var('job_no_prefix'));
		$search_location = get_query_var('location');
		$search_keyword = get_query_var('keyword');
		if ( !$gen_value ) {
			$location_value = strtolower(get_query_var('job_location'));
			$category_value = strtolower(get_query_var('job_category'));
			$company_value = strtolower(get_query_var('job_company'));
		} else {
			$category_value = CB_JobSearch::get_cb_category( $gen_value );
			if ( $category_value != false ) {
				$category_value = strtolower(get_query_var('job_no_prefix'));
			} else {
				$location_value = strtolower(get_query_var('job_no_prefix'));
			}
		}
		$cb_permalinks = $options['cb_permalinks'];
		if ( $location_value ) {
			$friendly_location_value = str_replace(',','_',$location_value);
			$friendly_location_value = explode('_', $friendly_location_value);
			if (count($friendly_location_value) > 1) {
				if (strlen($friendly_location_value[1]) == 2) {
					$friendly_location_value[1] = strtoupper($friendly_location_value[1]);
				}
				$friendly_location_value = implode(', ', $friendly_location_value);
			} else {
				$friendly_location_value = $location_value;
			}
			$friendly_location_value = str_replace('-',' ',$friendly_location_value);
			$friendly_location_value = ucwords($friendly_location_value);
			$search_location = $friendly_location_value;
			$cb_location_prefix = $options['cb_location_prefix'];	
			// if there is a prefix
			if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
				if ( $cb_permalinks == 1 ) {
					// rules for directory with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_location_prefix.'/'.$location_value;
				} else if ( $cb_permalinks == 3 ) {
					// rules for hyphenated with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_location_prefix.'/'.$location_value;
				}
			// if there is no prefix
			} else {
				if ( $cb_permalinks == 2 ) {
					// rules for directory
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$location_value;	
				} else if ( $cb_permalinks == 4 ) {
					// rules for hyphenated
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-in-'.$location_value;
				}
			}
		} else if ( $company_value ) {
			$cb_company_prefix = $options['cb_company_prefix'];
			// if there is a prefix
			if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
				if ( $cb_permalinks == 1 ) {
					// rules for directory with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_company_prefix.'/'.$company_value;
				} else if ( $cb_permalinks == 3 ) {
					// rules for hyphenated with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_company_prefix.'/'.$company_value;
				}
			// if there is no prefix
			} else {
				if ( $cb_permalinks == 2 ) {
					// rules for directory
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_company_prefix.'/'.$company_value;
				} else if ( $cb_permalinks == 4 ) {
					// rules for hyphenated
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-at-'.$company_value;
				}
			}
		} else if ( $category_value ) {
			$cb_category_prefix = $options['cb_category_prefix'];
			// if there is a prefix
			if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
				if ( $cb_permalinks == 1 ) {
					// rules for directory with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_category_prefix.'/'.$category_value;					
				} else if ( $cb_permalinks == 3 ) {
					// rules for hyphenated with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_category_prefix.'/'.$category_value;
				}
			// if there is no prefix
			} else {
				// need to get all query vars and see what the site calls them
				if ( $cb_permalinks == 2 ) {
					// rules for directory
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$category_value;
				} else if ( $cb_permalinks == 4 ) {
					// rules for hyphenated
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-in-'.$category_value;
				}
			}
		} else if ( $search_location || $search_keyword ) {
			$url['results_root'] = $bloghome.'/'.$cb_jobresults_page;
		}
		?>
		<form id="jobsearchform" name="jobsearchform" method="get" action="<?php echo $url['results_root']; ?>" class="group<?php echo $page;?>">
			<fieldset>
				<legend>Job Search</legend>
				<label for="keyword"><?php echo __('Keywords', 'careerbuilder_jobs'); ?> <?php if ($page == ' cb_jobs_home') { ?><small><?php echo __('Ex: Registered Nurse or Sales', 'careerbuilder_jobs'); ?></small><?php } ?></label>
				<input id="keyword" name="keyword" value="<?php echo $search_keyword;?>" />
				<label for="location"><?php echo __('Location', 'careerbuilder_jobs'); ?> <?php if ($page == ' cb_jobs_home') { ?><small><?php echo __('Ex: Chicago, IL or 60607', 'careerbuilder_jobs'); ?></small><?php } ?></label>
				<input id="location" name="location" value="<?php echo $search_location ;?>" />
				<input id="jobsearchsubmit" type="submit" value="<?php echo __('Search', 'careerbuilder_jobs'); ?>" class="group" />
			</fieldset>
		</form>
		<?php
	}
	
	/**
	 * CareerBuilder job results for display. Calls specific functions based on URL.
	 */
		function show_job_details() {
			global $wp_query, $wp_rewrite, $posts;
			$options = get_option('careerbuilder_jobs_options');
			// get job did from URL
			$job_id = get_query_var('job_did');
			$jobdid = explode("_",$job_id);
			$jobdid = $jobdid[1];
			// Get details for the job did.			
			$job_info = array();
			$job = CB_JobSearch::get_job_details( $jobdid );
			// recommended jobs
			if ( $options['cb_recommended_jobs'] == 1 ) {
				$job_info['recommended_jobs'] = CB_JobSearch::get_job_recommendations( $cb_developer_key,$jobdid );
			}
			// training links
			if ( $options['cb_training_resources'] == 1 ) {
				$job_info['training_resources'] = CB_JobSearch::get_training_resources($job->JobDescription,$job->JobRequirements,$job->Categories);
				if ( empty( $job_info['training_resources'] ) ) {
					$job_info['training_resources'] = '';
				}
			}
			// additional resources
			if ( $options['cb_additional_resources'] == 1 ) {
				$job_info['additional_resources'] = true;
			}
			
			/**
			* This file displays the content for Job Details. If you keep the default plugin settings, we'll include our CSS for this content, though you can write your own and remove ours with the plugin settings.
			 * You can also add a careerbuilder-job-details.php to your own theme, and completely reformat the way this content is included. If you have this file, we'll use it instead of ours.
			*/
			
			if (!@fopen($this->theme_dir.'/'.'careerbuilder-job-details.php', 'r')) {
				include( 'careerbuilder-job-details.php' );
			} else {
				// if the theme has a details page, use it
				include( $this->theme_path.'/'.'careerbuilder-job-details.php' );
			}
		}
	
	/**
	 * @return CareerBuilder job details for a specific job
	 */
	function get_job_details( $jobdid ) {
		global $wp_query, $wp_rewrite, $posts;
		// formatting for details
		include('careerbuilder-jobs-formatting.php');
		$options = get_option('careerbuilder_jobs_options');
		$cb_developer_key = $options['cb_developer_key'];
		$cb_siteid = 'wpp_'.$cb_developer_key;
		$cb_cobrand_code = $options['cb_cobrand_code'];
		$bloghome = get_bloginfo('wpurl');
		$cb_jobresults_page = $options['cb_jobresults_page'];
		$cb_jobdetails_page = $options['cb_jobdetails_page'];
		$joburl = "http://api.careerbuilder.com/v2/job/?DeveloperKey=$cb_developer_key&DID=$jobdid";
		try {
			$xml = simplexml_load_file( $joburl );
		} catch( Exception $e ) {
			print_r( $e );
		}
		if ( $xml ) {
			$job = $xml->Job;
			$company_string = urlencode( $job->Company );
			$companyjobs = CB_JobSearch::get_jobs_by_company( $cb_developer_key,$cb_siteid,$cb_cobrand_code,$company_string,$search_location,$search_keyword,1,1,30,'',false );
			$job->company_jobs_total = $companyjobs['machine_total'];
			$cityslug = sanitize_title( $job->LocationCity );
			$regionslug = sanitize_title( $job->LocationState );
			$location_value = $cityslug.'_'.$regionslug;
			$location_string = str_replace('-', '+', $location_value);
			$location_string = str_replace('_','+',$location_string);
			$cityjobs = CB_JobSearch::get_jobs_by_location( $cb_developer_key,$cb_siteid,$cb_cobrand_code,$location_string,$search_keyword,'1','1','30','',false );
			$job->city_jobs_total = $cityjobs['machine_total'];
			$job->LocationForURL = $cityslug.'_'.$regionslug;
			$job->CompanyForURL = sanitize_title( $job->Company );
			$job->CompanyHighlighted = cb_search_highlight( $job->Company );
			$job->LocationCityHighlighted = cb_search_highlight( $job->LocationCity );
			$job->LocationStateHighlighted = cb_search_highlight($job->LocationState );
			$job->JobDescription = cb_search_highlight( cb_clean_desc( $job->JobDescription ) );
			$job->JobRequirements = cb_search_highlight( cb_clean_desc( $job->JobRequirements ) );
			$cb_permalinks = $options['cb_permalinks'];
			$cb_location_prefix = $options['cb_location_prefix'];
			$cb_category_prefix = $options['cb_category_prefix'];
			$cb_company_prefix = $options['cb_company_prefix'];
			// if there is a prefix
			if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
				if ( $cb_permalinks == 1 ) {
					// rules for directory with prefixes
					$job['location_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_location_prefix.'/';
					$job['category_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_category_prefix.'/';
					$job['company_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_company_prefix.'/';
				} else if ( $cb_permalinks == 3 ) {
					// rules for hyphenated with prefixes
					$job['location_root'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_location_prefix.'/';
					$job['category_root'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_category_prefix.'/';
					$job['company_root'] = $bloghome.'/'.$cb_jobresults_page.'-at-'.$cb_company_prefix.'/';
				}
			// if there is no prefix
			} else {
				if ( $cb_permalinks == 2 ) {
					// rules for directory
					$job['location_root'] = $bloghome.'/'.$cb_jobresults_page.'/';	
					$job['category_root'] = $bloghome.'/'.$cb_jobresults_page.'/';
					$job['company_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_company_prefix.'/';
				} else if ( $cb_permalinks == 4 ) {
					// rules for hyphenated
					$job['location_root'] = $bloghome.'/'.$cb_jobresults_page.'-in-';
					$job['category_root'] = $bloghome.'/'.$cb_jobresults_page.'-in-';
					$job['company_root'] = $bloghome.'/'.$cb_jobresults_page.'-at-'.$cb_company_prefix;
				}
			}
			return $job;
		} else {
			$wp_query->is_404=true;
		}
	}
	
	/**
	 * @return CareerBuilder Institute training resources
	 * This is, by default, used in the job details page
	 */
	function get_training_resources( $description,$requirements,$categories ) {
		$categories = explode( ',  ', $categories );
		$trainingurl = "http://careerbuildermarketing.com/cbinstitute/by_category.xml";
		try {
			$xml = simplexml_load_file( $trainingurl );
		} catch( Exception $e ) {
			print_r( $e );
		}
		if ( $xml ) {
			$trainings = array();
			// check category list for matching training categories
			$trainingcategories = $xml->categories;
			$key = 0;
			foreach ( $trainingcategories->category as $trainingcategory ) {
				$id = $trainingcategory->id;
				$url = $trainingcategory->url;
				$jobcats = $trainingcategory->jobcats;
				foreach ( $jobcats->jobcat->name as $jobcat ) {
					if ( in_array( $jobcat, $categories ) ) {
						$jobcat = htmlentities($jobcat);
						$trainings[$key]['title'] = "Training for $jobcat";
						$query = "siteid=wpp_cat$id";
						$url = "$url";
						if ( strpos( $url,'?' )) {
							$trainings[$key]['url'] = $url.'&amp;'.$query;
						} else {
							$trainings[$key]['url'] = $url.'?'.$query;
						}
						$key++;
					}
				}
			}
			return $trainings;
		} else {
			return '';
		}
	}
	
	/**
	 * @return job categories available from the CareerBuilder API.
	 * This function will cache the results if it is able, and will check to see if the file is greater than the cache store time.
	 */	
	function get_cb_categories() {
		// See if there is a cache file newer than one week old. Load it, if so.
		$cb_cachetime = 604800;
		$options = get_option('careerbuilder_jobs_options');
		// See if there is a cache file newer than the cache storage time. Load it, if so.
		$cachedir = WP_PLUGIN_DIR . '/careerbuilder-jobs/cache';
		$cachefile = $cachedir.'/categories.xml';
		$cacheurl = $cachedir.'/categories.xml';
		if ( file_exists($cachefile) && ( time() - $cb_cachetime < filemtime($cachefile) ) || !is_writable( $cachefile ) ) {
			try {
				$xml = simplexml_load_file( $cacheurl );
			} catch( Exception $e ) {
				print_r( $e );
			}
			if ( $xml ) {
				$categories = $xml->Categories;
				$cached_success = 1;
			}
		}
		// Otherwise, get category code list from the CB API. Cache it if we can.
		if ( $cached_success != 1 && is_writable( $cachefile ) ) {
			$cb_developer_key = $this->cb_developer_key;
			$cb_country_code = $options['cb_country_code'];
			if ( isset($options['cb_international']) ) {
				$cb_international = $options['cb_international'];
			} else {
				$cb_international = false;
			}
			if ( $cb_developer_key ) {
				$url = 'http://api.careerbuilder.com/v2/categories?developerkey='.$cb_developer_key;
				if ( $cb_international == true ) {
					$url = $url.'&countrycode='.$cb_country_code;
				}
				try {
					$xml = simplexml_load_file( $url );
				} catch( Exception $e ) {
					print_r( $e );
				}
				if ( $xml ) {
					$categories = $xml->Categories;
					// cache if we can
					/* At this time, we can only cache US results to preserve language formatting, as the API does not return language codes for corresponding countries. */
					if ( $cb_international == false ) {
						if ( is_dir($cachedir) ) {
							ob_start();
							$contents .= "<?xml version=\"1.0\"?>\n<ResponseCategories>\n<Categories>\n";
							foreach ( $categories->Category as $category ) {
								$code = $category->Code;
								$name = $category->Name;
								$contents .= "<Category>\n<Code>$code</Code>\n<Name language=\"en-US\">$name</Name>\n</Category>\n";
							}
							$contents .= "</Categories>\n</ResponseCategories>";
							$fp = fopen($cachefile, 'w'); 
							fwrite($fp, $contents);
							fclose($fp);
						}
					}
				}
			} else {
				// In this case, there is no developer key and no cached file.
				$categories = _e("All Categories", 'careerbuilder_jobs');
			}
		}
		return $categories;
	}
	
	/**
	 * @return category information based on a slug. Returns false if it does not match a category. Returns the category's title from the currently cached XML file if it does match.
	 */
	function get_cb_category( $slug ) {
		$category = false;
		$categories = CB_JobSearch::get_cb_categories();	
		foreach ( $categories->Category as $cb_category ) {
			$name = $cb_category->Name;
			$catslug = trim( $name );
			$catslug = sanitize_title( $catslug );
			$catslugs[] = $catslug;
			$catnames[] = $name;
		}
		if ( $key = array_search( $slug, $catslugs ) ) {
			$category = $catnames[$key];
		}
		return $category;
	}
	
	/**
	 * @return job locations from the static XML file.
	 * If the argument for region is present, this function returns locations for that region. I.E. cities in Illinois. Otherwise, it returns all regions and their cities.
	 * This is not currently available in the API, but the plugin will be updated in the event that it is.
	 */	
	function get_cb_locations( $region_name ) {
		// load the xml file
		$cachedir = WP_PLUGIN_DIR . '/careerbuilder-jobs/cache';
		$cachefile = $cachedir.'/locations.xml';
		$cacheurl = $cachedir.'/locations.xml';
		try {
			$xml = simplexml_load_file( $cacheurl );
		} catch( Exception $e ) {
			print_r( $e );
		}
		if ( $xml ) {
			if ( $region_name == '' ) {
				return $xml;
			} else {
				$filter = $xml->xpath("//region[@name='$region_name']");
				$cities = $filter[0];
				return $cities;
			}
		}
	}
	
	/**
	 * @return country specific codes available from the CareerBuilder API
	 * This function will cache the results if server is capable, and will check to see if the file is greater than the cache store time.
	 */
	function get_cb_countries() {
		// See if there is a cache file newer than one week old. Load it, if so.
		$cb_cachetime = 604800;
		$options = get_option('careerbuilder_jobs_options');
		// See if there is a cache file newer than the cache storage time. Load it, if so.
		$cachedir = WP_PLUGIN_DIR . '/careerbuilder-jobs/cache';
		$cachefile = $cachedir.'/countries.xml';
		$cacheurl = $cachedir.'/countries.xml';
		if ( file_exists($cachefile) && ( time() - $cb_cachetime < filemtime($cachefile) ) || !is_writable( $cachefile ) ) {
			try {
				$xml = simplexml_load_file( $cacheurl );
			} catch( Exception $e ) {
				print_r( $e );
			}
			if ( $xml ) {
				$countries = $xml->SupportedCountryCodes;
				$cached_success = 1;
			}
		}
		// Otherwise, get country code list from the CB API. Cache it if allowed.
		if ( $cached_success != 1 && is_writable( $cachefile ) ) {
			$options = get_option('careerbuilder_jobs_options');
			$cb_developer_key = $this->cb_developer_key;
			if ( $cb_developer_key ) {
				$url = 'http://api.careerbuilder.com/v2/countrycodes?DeveloperKey='.$cb_developer_key;
				try {
					$xml = simplexml_load_file( $url );
				} catch( Exception $e ) {
					print_r( $e );
				}
				if ( $xml ) {
					$countries = $xml->SupportedCountryCodes;
					// cache if we can
					if ( is_dir($cachedir) ) {
						ob_start();
						$contents .= "<?xml version=\"1.0\"?>\n<ResponseCountryCodes>\n<SupportedCountryCodes>\n";
						foreach ( $countries->CountryCode as $country ) {
							$contents .= "<CountryCode>$country</CountryCode>\n";
						}
						$contents .= "</SupportedCountryCodes>\n</ResponseCountryCodes>";
						$fp = fopen($cachefile, 'w'); 
						fwrite($fp, $contents);
						fclose($fp);
					}
				}
			}
		}
		return $countries;
	}
		
  /**
	 * Set up settings page and option fields
	 */	
	function add_settings_page() {
		$page = add_options_page(__('CareerBuilder Jobs', 'careerbuilder_jobs'), __('CareerBuilder Jobs', 'careerbuilder_jobs'), 8, __FILE__, array('CB_JobSearch', 'settings_page'));
	}
	
	function cb_admin_styles() {
		wp_enqueue_style('cb_plugin_stylesheet');
	}
	
	function cb_admin_scripts() {
		wp_enqueue_script('cb_plugin_javascript', $cbpluginscript, array('jquery'));
	}
	
		function cbjobs_admin_init() {
			wp_register_style('cb_plugin_stylesheet', WP_PLUGIN_URL . '/careerbuilder-jobs/cb-plugin.css');
			wp_register_script('cb_plugin_javascript', WP_PLUGIN_URL . '/careerbuilder-jobs/cb-plugin.js');
			register_setting('careerbuilder_jobs_options', 'careerbuilder_jobs_options', array('CB_JobSearch', 'sanitize_settings'));
			
			// create sections for settings, descriptive text if applicable
			add_settings_section('careerbuilder_jobs_main', __('Required Settings', 'careerbuilder_jobs'), array('CB_JobSearch', 'careerbuilder_jobs_required'), 'careerbuilder_jobs');
			add_settings_section('careerbuilder_jobs_permalinks', __('Permalink Settings', 'careerbuilder_jobs'), array('CB_JobSearch', 'careerbuilder_jobs_permalinks'), 'careerbuilder_jobs');
			add_settings_section('careerbuilder_jobs_optional', __('Optional &amp; Advanced Settings', 'careerbuilder_jobs'), array('CB_JobSearch', 'careerbuilder_jobs_optional'), 'careerbuilder_jobs');
			
			// required fields
			add_settings_field('cb_developer_key', '<label for="cb_developer_key">CareerBuilder <a href="http://api.careerbuilder.com/RequestDevKey.aspx">'.__('Developer Key', 'careerbuilder_jobs').'</a>:</label>', array('CB_JobSearch', 'cb_developer_key'), 'careerbuilder_jobs', 'careerbuilder_jobs_main');
			add_settings_field('cb_jobresults_page', '<label for="cb_jobresults_page">'.__('Job Results Page', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_jobresults_page'), 'careerbuilder_jobs', 'careerbuilder_jobs_main');
			add_settings_field('cb_jobdetails_page', '<label for="cb_jobdetails_page">'.__('Job Details Page', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_jobdetails_page'), 'careerbuilder_jobs', 'careerbuilder_jobs_main');
			add_settings_field('cb_location_prefix', '<label for="cb_location_prefix">'.__('Location Prefix', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_location_prefix'), 'careerbuilder_jobs', 'careerbuilder_jobs_main');		
			add_settings_field('cb_category_prefix', '<label for="cb_category_prefix">'.__('Category Prefix', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_category_prefix'), 'careerbuilder_jobs', 'careerbuilder_jobs_main');
			add_settings_field('cb_company_prefix', '<label for="cb_company_prefix">'.__('Company Prefix', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_company_prefix'), 'careerbuilder_jobs', 'careerbuilder_jobs_main');		
			add_settings_field('cb_jobs_perpage', '<label for="cb_jobs_perpage">'.__('Jobs Per Page', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_jobs_perpage'), 'careerbuilder_jobs', 'careerbuilder_jobs_main');
			add_settings_field('cb_jobs_perfeed', '<label for="cb_jobs_perfeed">'.__('Jobs In Feed', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_jobs_perfeed'), 'careerbuilder_jobs', 'careerbuilder_jobs_main');
			add_settings_field('cb_jobs_postedwithin', '<label for="cb_jobs_postedwithin">'.__('Jobs Posted Within', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_jobs_postedwithin'), 'careerbuilder_jobs', 'careerbuilder_jobs_main');
			
			// permalink setting fields
			add_settings_field('cb_permalinks', '<label for="cb_permalinks">'.__('Permalink Structure', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_permalinks'), 'careerbuilder_jobs', 'careerbuilder_jobs_permalinks');
			
			// optional fields
			add_settings_field('cb_training_resources', '<label for="cb_training_resources">'.__('Get CB Training Links', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_training_resources'), 'careerbuilder_jobs', 'careerbuilder_jobs_optional');
			add_settings_field('cb_additional_resources', '<label for="cb_additional_resources">'.__('Show Additional Resources', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_additional_resources'), 'careerbuilder_jobs', 'careerbuilder_jobs_optional');
			add_settings_field('cb_recommended_jobs', '<label for="cb_recommended_jobs">'.__('Show Recommended Jobs', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_recommended_jobs'), 'careerbuilder_jobs', 'careerbuilder_jobs_optional');
			add_settings_field('cb_allow_tooltips', '<label for="cb_allow_tooltips">'.__('Show Job Detail Tooltips', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_allow_tooltips'), 'careerbuilder_jobs', 'careerbuilder_jobs_optional');
			add_settings_field('cb_default_css', '<label for="cb_default_css">'.__('Remove Default CSS', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_default_css'), 'careerbuilder_jobs', 'careerbuilder_jobs_optional');
			add_settings_field('cb_default_js', '<label for="cb_default_js">'.__('Remove Default JavaScript', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_default_js'), 'careerbuilder_jobs', 'careerbuilder_jobs_optional');
			add_settings_field('cb_default_searchform', '<label for="cb_default_searchform">'.__('Remove Default Job Search Form', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_default_searchform'), 'careerbuilder_jobs', 'careerbuilder_jobs_optional');
			add_settings_field('cb_job_category', '<label for="cb_job_category">'.__('Limit Job Category', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_job_category'), 'careerbuilder_jobs', 'careerbuilder_jobs_optional');
			add_settings_field('cb_country_code', '<label for="cb_country_code">'.__('Country Code', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_country_code'), 'careerbuilder_jobs', 'careerbuilder_jobs_optional');
			add_settings_field('cb_default_location', '<label for="cb_default_location">'.__('Default Location', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_default_location'), 'careerbuilder_jobs', 'careerbuilder_jobs_optional');
			add_settings_field('cb_default_company', '<label for="cb_default_company">'.__('Default Company', 'careerbuilder_jobs').':</label>', array('CB_JobSearch', 'cb_default_company'), 'careerbuilder_jobs', 'careerbuilder_jobs_optional');
			

			add_settings_field('cb_cobrand_code', '<label for="cb_cobrand_code">'.__('CareerBuilder Cobrand Code:', 'careerbuilder_jobs').'</label>', array('CB_JobSearch', 'cb_cobrand_code'), 'careerbuilder_jobs', 'careerbuilder_jobs_optional');
		}
	 
		function careerbuilder_jobs_required() {
			echo '<p>'.__("These settings must have values for the plugin to work, though you can use the default value for fields that have one. Remember that the Job Results Page and Job Details Page values refer to actual WordPress pages where you'll need to include template tags. Check the readme for details.", 'careerbuilder_jobs').'</p>';
		}
	
		function cb_developer_key() {
			$options = get_option('careerbuilder_jobs_options');
			echo "<input id='cb_developer_key' name='careerbuilder_jobs_options[cb_developer_key]' size='40' type='text' value='{$options['cb_developer_key']}' />";
		}
		
		function cb_jobresults_page() {
			$options = get_option('careerbuilder_jobs_options');
			if ( $options['cb_jobresults_page'] == '' ) {
				$options['cb_jobresults_page'] = 'jobs';
			}			
			echo '<select id="cb_jobresults_page" name="careerbuilder_jobs_options[cb_jobresults_page]"> 
			 <option value="">Select Page</option>';
			  $pages = get_pages(); 
			  foreach ( $pages as $pagg ) {
			  	if ( $pagg->post_name == $options['cb_jobresults_page'] ) {
			  		$selected = ' selected="selected"';
			  	} else {
			  		$selected = '';
			  	}
			  	$option = '<option value="'.$pagg->post_name.'"'.$selected.'">'.$pagg->post_title.'</option>';
					echo $option;
			  }
			echo '</select>';
			$bloginfo = get_bloginfo('wpurl');
			echo "<p class=\"site_url\">Ex: $bloginfo/<span class=\"job_url\">".$options['cb_jobresults_page']."</span></p>";
		}
	
		function cb_jobdetails_page() {
			$options = get_option('careerbuilder_jobs_options');
			if ( $options['cb_jobdetails_page'] == '' ) {
				$options['cb_jobdetails_page'] = 'job';
			}
			echo '<select id="cb_jobdetails_page" name="careerbuilder_jobs_options[cb_jobdetails_page]"> 
			<option value="">Select Page</option>';
			  $pages = get_pages(); 
			  foreach ($pages as $pagg) {
			  	if ( $pagg->post_name == $options['cb_jobdetails_page'] ) {
			  		$selected = ' selected="selected"';
			  	} else {
			  		$selected = '';
			  	}
			  	$option = '<option value="'.$pagg->post_name.'"'.$selected.'">'.$pagg->post_title.'</option>';
					echo $option;
			  }
			echo '</select>';
			$bloginfo = get_bloginfo('wpurl');
			echo "<p class=\"site_url\">Ex: $bloginfo/<span class=\"jobdetail_url\">".$options['cb_jobdetails_page']."</span>/jobtitle_id</p>";
		}
	
		function cb_location_prefix() {
			$options = get_option('careerbuilder_jobs_options');
			if ( $options['cb_location_prefix'] == '' ) {
				$options['cb_location_prefix'] = 'location';
			}
			echo "<input id='cb_location_prefix' name='careerbuilder_jobs_options[cb_location_prefix]' size='40' type='text' value='{$options['cb_location_prefix']}' />";
			$bloginfo = get_bloginfo('wpurl');
			echo "<p class=\"site_url\">Ex: $bloginfo/<span class=\"job_url\">".$options['cb_jobresults_page']."</span>/<span class=\"location_url\">".$options['cb_location_prefix']."</span></p>";
		}
			
		function cb_category_prefix() {
			$options = get_option('careerbuilder_jobs_options');
			if ( $options['cb_category_prefix'] == '' ) {
				$options['cb_category_prefix'] = 'category';
			}
			echo "<input id='cb_category_prefix' name='careerbuilder_jobs_options[cb_category_prefix]' size='40' type='text' value='{$options['cb_category_prefix']}' />";
			$bloginfo = get_bloginfo('wpurl');
			echo "<p class=\"site_url\">Ex: $bloginfo/<span class=\"job_url\">".$options['cb_jobresults_page']."</span>/<span class=\"category_url\">".$options['cb_category_prefix']."</span></p>";
		}
	
		function cb_company_prefix() {
			$options = get_option('careerbuilder_jobs_options');
			if ( $options['cb_company_prefix'] == '' ) {
				$options['cb_company_prefix'] = 'company';
			}
			echo "<input id='cb_company_prefix' name='careerbuilder_jobs_options[cb_company_prefix]' size='40' type='text' value='{$options['cb_company_prefix']}' />";
			$bloginfo = get_bloginfo('wpurl');
			echo "<p class=\"site_url\">Ex: $bloginfo/<span class=\"job_url\">".$options['cb_jobresults_page']."</span>/<span class=\"company_url\">".$options['cb_company_prefix']."</span></p>";
		}
		
		function cb_jobs_perpage() {
			$options = get_option('careerbuilder_jobs_options');
			if ( $options['cb_jobs_perpage'] == '' ) {
				$options['cb_jobs_perpage'] = 10;
			}
			echo "<input id='cb_jobs_perpage' name='careerbuilder_jobs_options[cb_jobs_perpage]' size='40' type='text' value='{$options['cb_jobs_perpage']}' />";
		}
		
		function cb_jobs_perfeed() {
			$options = get_option('careerbuilder_jobs_options');
			if ( $options['cb_jobs_perfeed'] == '' ) {
				$options['cb_jobs_perfeed'] = 25;
			}
			echo "<input id='cb_jobs_perfeed' name='careerbuilder_jobs_options[cb_jobs_perfeed]' size='40' type='text' value='{$options['cb_jobs_perfeed']}' />";
		}
	
		function cb_jobs_postedwithin() {
			$options = get_option('careerbuilder_jobs_options');
			if ( $options['cb_jobs_postedwithin'] == 1) {
				$selected1 = 'selected="selected"';
				$selected2 = '';
				$selected3 = '';
				$selected4 = '';
			} else if ( $options['cb_jobs_postedwithin'] == 3) {
				$selected1 = '';
				$selected2 = 'selected="selected"';
				$selected3 = '';
				$selected4 = '';
			} else if ( $options['cb_jobs_postedwithin'] == 7) {
				$selected1 = '';
				$selected2 = '';
				$selected3 = 'selected="selected"';
				$selected4 = '';
			} else if ( $options['cb_jobs_postedwithin'] == '' || $options['cb_jobs_postedwithin'] == 30) {
				$selected1 = '';
				$selected2 = '';
				$selected3 = '';
				$selected4 = 'selected="selected"';
			}
			echo '<select id="cb_jobs_postedwithin" name="careerbuilder_jobs_options[cb_jobs_postedwithin]">';
				echo '<option value="1"'.$selected1.'>'.__('1 Day', 'careerbuilder_jobs').'</option>';
				echo '<option value="3"'.$selected2.'>'.__('3 Days', 'careerbuilder_jobs').'</option>';
				echo '<option value="7"'.$selected3.'>'.__('7 Days', 'careerbuilder_jobs').'</option>';
				echo '<option value="30"'.$selected4.'>'.__('30 Days', 'careerbuilder_jobs').'</option>';
			echo '</select';
		}
		
		function careerbuilder_jobs_permalinks() {
			echo '<p>'.__('You can choose how you would like job listing URLs to work. Feel free to leave them as they are, but if you have specific SEO or usability preferences, you can customize them with any of these options. Note that if you change these, just like normal WordPress permalinks, you will have to set up redirects if you want the old ones to continue working.', 'careerbuilder_jobs').'</p>';
		}
	
		function cb_permalinks() {
			$bloginfo = get_bloginfo('wpurl');
			$options = get_option('careerbuilder_jobs_options');
			if ( $options['cb_permalinks'] == 1 ) {
				$checked1 = ' checked="checked" ';
				$checked2 = '';
				$checked3 = '';
				$checked4 = '';
			} else if ( $options['cb_permalinks'] == 2 ) {
				$checked1 = '';
				$checked2 = ' checked="checked" ';
				$checked3 = '';
				$checked4 = '';
			} else if ( $options['cb_permalinks'] == 3 ) {
				$checked1 = '';
				$checked2 = '';
				$checked3 = ' checked="checked" ';
				$checked4 = '';
			} else if ( $options['cb_permalinks'] == 4 ) {
				$checked1 = '';
				$checked2 = '';
				$checked3 = '';
				$checked4 = ' checked="checked" ';
			}
			echo '<div class="cb_permalink"><label><input id="cb_permalinks_1" name="careerbuilder_jobs_options[cb_permalinks]" type="radio" value="1"'.$checked1.'/> '.__('Directory with Prefixes', 'careerbuilder_jobs').'</label><code class="site_url">Ex: '.$bloginfo.'/<span class="job_url">'.$options['cb_jobresults_page'].'</span>/<span class="location_url">'.$options['cb_location_prefix'].'</span>/chicago</code></div>';
			echo '<div class="cb_permalink"><label><input id="cb_permalinks_2" name="careerbuilder_jobs_options[cb_permalinks]" type="radio" value="2"'.$checked2.'/> '.__('Directory', 'careerbuilder_jobs').'</label><code class="site_url">Ex: '.$bloginfo.'/<span class="job_url">'.$options['cb_jobresults_page'].'</span>/chicago</code></div>';
			echo '<div class="cb_permalink"><label><input id="cb_permalinks_3" name="careerbuilder_jobs_options[cb_permalinks]" type="radio" value="3"'.$checked3.'/> '.__('Hyphenated with Prefixes', 'careerbuilder_jobs').'</label><code class="site_url">Ex: '.$bloginfo.'/<span class="job_url">'.$options['cb_jobresults_page'].'</span>-by-<span class="location_url">'.$options['cb_location_prefix'].'</span>/chicago</code></div>';
			echo '<div class="cb_permalink"><label><input id="cb_permalinks_4" name="careerbuilder_jobs_options[cb_permalinks]" type="radio" value="4"'.$checked4.'/> '.__('Hyphenated', 'careerbuilder_jobs').'</label><code class="site_url">Ex: '.$bloginfo.'/<span class="job_url">'.$options['cb_jobresults_page'].'</span>-in-chicago</code></div>';
		}
	
		function careerbuilder_jobs_optional() {
			echo '<p>'.__('These are more advanced settings. Some of these allow you to display content from other CareerBuilder sites, like <a href="http://www.cbsalary.com/">CBsalary</a> or <a href="http://www.careerbuilderinstitute.com/">CareerBuilder Institute</a>. Others can tailor the search experience by company, location, category, etc. if this is relevant to your site. Also, if you choose to, you can take control over the CSS and JavaScript generated by the plugin if you would rather write your own.', 'careerbuilder_jobs').'</p>';
		}
		
		function cb_training_resources() {
			$options = get_option('careerbuilder_jobs_options');
			if ( isset($options['cb_training_resources']) && $options['cb_training_resources'] == 1 ) {
				$checked = ' checked="checked" ';
			} else {
				$checked = '';
			}
			echo '<label><input id="cb_training_resources" name="careerbuilder_jobs_options[cb_training_resources]" type="checkbox" value="1"'.$checked.'/>'.__(' Include relevant training links from ', 'careerbuilder_jobs').'<a href="http://www.careerbuilderinstitute.com/">'.__('CareerBuilder Institute', 'careerbuilder_jobs').'</a>.</label>';
		}
		
		function cb_additional_resources() {
			$options = get_option('careerbuilder_jobs_options');
			if ( isset($options['cb_additional_resources']) && $options['cb_additional_resources'] == 1 ) {
				$checked = ' checked="checked" ';
			} else {
				$checked = '';
			}
			echo '<label><input id="cb_additional_resources" name="careerbuilder_jobs_options[cb_additional_resources]" type="checkbox" value="1"'.$checked.'/>'.__(' Include additional CareerBuilder resources like ', 'careerbuilder_jobs').'<a href="http://www.cbsalary.com/">'.__('CBsalary', 'careerbuilder_jobs').'</a> '.__('when relevant.', 'careerbuilder_jobs').'</label>';
		}
		
		function cb_recommended_jobs() {
			$options = get_option('careerbuilder_jobs_options');
			if ( isset($options['cb_recommended_jobs']) && $options['cb_recommended_jobs'] == 1 ) {
				$checked = ' checked="checked" ';
			} else {
				$checked = '';
			}
			echo '<label><input id="cb_recommended_jobs" name="careerbuilder_jobs_options[cb_recommended_jobs]" type="checkbox" value="1"'.$checked.'/>'.__(' Include recommended jobs from our matching engine when available.').'</label>';
		}
		
		function cb_allow_tooltips() {
			$options = get_option('careerbuilder_jobs_options');
			if ( isset($options['cb_allow_tooltips']) && $options['cb_allow_tooltips'] == 1 ) {
				$checked = ' checked="checked" ';
			} else {
				$checked = '';
			}
			echo '<label><input id="cb_allow_tooltips" name="careerbuilder_jobs_options[cb_allow_tooltips]" type="checkbox" value="1"'.$checked.'/>'.__(' This displays extra information to users on job detail pages. This includes basic city and company information, for example.', 'careerbuilder_jobs').'</label>';
		}
	
		function cb_default_css() {
			$cbstyleurl = WP_PLUGIN_URL . '/careerbuilder_jobs/cb-jobs-default.css';
			$options = get_option('careerbuilder_jobs_options');
			if ( isset($options['cb_default_css']) && $options['cb_default_css'] == 1 ) {
				$checked = ' checked="checked" ';
			} else {
				$checked = '';
			}
			echo '<label><input id="cb_default_css" name="careerbuilder_jobs_options[cb_default_css]" type="checkbox" value="1"'.$checked.'/>'.__(' You intend to create your own styles for displaying plugin data. If you leave this unchecked, we will include our default ', 'careerbuilder_jobs').'<a href="'.$cbstyleurl.'">'.__('styles', 'careerbuilder_jobs').'</a> '.__('.', 'careerbuilder_jobs').'</label>';
		}
		
		function cb_default_js() {
			$cbscripturl = WP_PLUGIN_URL . '/careerbuilder_jobs/cb-jobs-default.js';
			$options = get_option('careerbuilder_jobs_options');
			if ( isset($options['cb_default_js']) && $options['cb_default_js'] == 1 ) {
				$checked = ' checked="checked" ';
			} else {
				$checked = '';
			}
			echo '<label><input id="cb_default_js" name="careerbuilder_jobs_options[cb_default_js]" type="checkbox" value="1"'.$checked.'/>'.__(' You intend to create your own JavaScript for plugin interactivity. If you leave this unchecked, we will include our default ', 'careerbuilder_jobs').'<a href="'.$cbscripturl.'">'.__('JavaScript file.', 'careerbuilder_jobs').'</a> '.__('.', 'careerbuilder_jobs').'</label>';
		}
		
		function cb_default_searchform() {
			$options = get_option('careerbuilder_jobs_options');
			if ( isset($options['cb_default_searchform']) && $options['cb_default_searchform'] == 1 ) {
				$checked = ' checked="checked" ';
			} else {
				$checked = '';
			}
			echo '<label><input id="cb_default_searchform" name="careerbuilder_jobs_options[cb_default_searchform]" type="checkbox" value="1"'.$checked.'/>'.__(' You want to manually place a job search form within your theme. If you leave this unchecked, we will include our default form on the jobs home page, and the job results pages.', 'careerbuilder_jobs').'</label>';
		}

		function cb_job_category() {
			$categories = CB_JobSearch::get_cb_categories();
			$options = get_option('careerbuilder_jobs_options');
			$cb_category_code = $options['cb_job_category'];
			echo '<select name="careerbuilder_jobs_options[cb_job_category]" id="cb_job_category">';
				echo '<option value="">'.__('All Categories', 'careerbuilder_jobs').'</option>';
				if ( is_object($categories) ) {
					foreach ( $categories->Category as $category ) {
						$code = $category->Code;
						$name = $category->Name;
						if ( $code == $cb_category_code ) {
							echo '<option value="'.$code.'" selected="selected">'.__("$name", 'careerbuilder_jobs').'</option>';
						} else {
							echo '<option value="'.$code.'">'.__("$name", 'careerbuilder_jobs').'</option>';
						}
					}
				}
			echo '</select>';
		}
		
		function cb_country_code() {
			$countries = CB_JobSearch::get_cb_countries();
			$options = get_option('careerbuilder_jobs_options');
			$cb_country_code = $options['cb_country_code'];
			if ( $cb_country_code == '' ) {
				$cb_country_code = __('US', 'careerbuilder_jobs');
			}
			echo '<select name="careerbuilder_jobs_options[cb_country_code]" id="cb_country_code">';
				echo '<option value="">'.__('Select One', 'careerbuilder_jobs').'</option>';
				if ( is_object($countries) ) {
					foreach ( $countries->CountryCode as $country ) {
						if ( $country == $cb_country_code ) {
							echo '<option value="'.$country.'" selected="selected">'.__("$country", 'careerbuilder_jobs').'</option>';
						} else {
							echo '<option value="'.$country.'">'.__("$country", 'careerbuilder_jobs').'</option>';
						}
					}
				} else {
					echo '<option value="US">'.__('US', 'careerbuilder_jobs').'</option>';
				}
			echo '</select>';
		}
	
		function cb_default_location() {
			$options = get_option('careerbuilder_jobs_options');
			echo "<input id='cb_default_location' name='careerbuilder_jobs_options[cb_default_location]' size='40' type='text' value='{$options['cb_default_location']}' />";
		}
		
		function cb_default_company() {
			$options = get_option('careerbuilder_jobs_options');
			echo "<input id='cb_default_company' name='careerbuilder_jobs_options[cb_default_company]' size='40' type='text' value='{$options['cb_default_company']}' />";
		}
		
		function cb_cobrand_code() {
			$options = get_option('careerbuilder_jobs_options');
			echo "<input id='cb_cobrand_code' name='careerbuilder_jobs_options[cb_cobrand_code]' size='40' type='text' value='{$options['cb_cobrand_code']}' />";
		}
		
		/**
		 * @return sanitized values for user inputs in the plugin settings.
		 * This takes the array of plugin settings, validates/escapes the values depending on what is expected, and creates an array of the accepted fields. This array is returned, removing any undesired fields.
		 */
		function sanitize_settings($input) {
			$goodinput['cb_developer_key'] = esc_html( $input['cb_developer_key'] );
			$goodinput['cb_jobresults_page'] = esc_html( $input['cb_jobresults_page'] );
			$goodinput['cb_jobdetails_page'] = esc_html( $input['cb_jobdetails_page'] );
			$goodinput['cb_location_prefix'] = esc_html( $input['cb_location_prefix'] );
			$goodinput['cb_category_prefix'] = esc_html( $input['cb_category_prefix'] );
			$goodinput['cb_company_prefix'] = esc_html( $input['cb_company_prefix'] );
			$goodinput['cb_jobs_perpage'] = absint( $input['cb_jobs_perpage'] );
			$goodinput['cb_jobs_perfeed'] = absint( $input['cb_jobs_perfeed'] );
			$goodinput['cb_jobs_postedwithin'] = absint( $input['cb_jobs_postedwithin'] );
			$goodinput['cb_permalinks'] = absint( $input['cb_permalinks'] );
			$goodinput['cb_training_resources'] = ( $input['cb_training_resources'] == 1 ? 1  : 0 );
			$goodinput['cb_additional_resources'] = ( $input['cb_additional_resources'] == 1 ? 1  : 0 );
			$goodinput['cb_recommended_jobs'] = ( $input['cb_recommended_jobs'] == 1 ? 1  : 0 );
			$goodinput['cb_allow_tooltips'] = ( $input['cb_allow_tooltips'] == 1 ? 1  : 0 );
			$goodinput['cb_default_css'] = ( $input['cb_default_css'] == 1 ? 1  : 0 );
			$goodinput['cb_default_js'] = ( $input['cb_default_js'] == 1 ? 1  : 0 );
			$goodinput['cb_default_searchform'] = ( $input['cb_default_searchform'] == 1 ? 1  : 0 );
			$goodinput['cb_job_category'] = esc_html( $input['cb_job_category'] );
			$goodinput['cb_country_code'] = esc_html( $input['cb_country_code'] );
			$goodinput['cb_default_location'] = esc_html( $input['cb_default_location'] );
			$goodinput['cb_default_company'] = esc_html( $input['cb_default_company'] );
			$goodinput['cb_cobrand_code'] = esc_html( $input['cb_cobrand_code'] );
			return $goodinput;
		}
	 
	/** Generates the settings page from the above options **/
	function settings_page() {
		//global $cbDeveloper;
	?>

	<div class="wrap">
		<h2><?php echo __('CareerBuilder Jobs Settings', 'careerbuilder_jobs'); ?></h2>
		<form action="options.php"  method="post">
			<?php settings_fields('careerbuilder_jobs_options'); ?>
			<?php do_settings_sections('careerbuilder_jobs'); ?>
			<p class="submit"><input name="Submit" type="submit" class="button-primary" value="<?php esc_attr_e('Save Changes'); ?>" /></p>
		</form>
	</div>
		<?php
	}

	/**
	 * Inserts the settings link on the plugin's page
	 *
	 */
	function settings_link( $links ) {
		$settings_link = '<a href="options-general.php?page=' . plugin_basename(__FILE__) . '">' . __('Settings', 'careerbuilder_jobs') . '</a>';
		array_unshift( $links, $settings_link );
		return $links;
	}
	
	/**
	 * Registers a job search widget for the sidebar. This is optional.
	 *
	 */
	function cb_load_widgets() {
		register_widget( 'CBJobSearch_Widget' );
	}

}

/**      
 * Job Search Widget
 */
class CBJobSearch_Widget extends WP_Widget {

	function CBJobSearch_Widget() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'cbjobsearch', 'description' => 'Careerbuilder job search form with keyword and location fields.' );
		/* Widget control settings. */
		$control_ops = array( 'width' => 300, 'height' => 200, 'id_base' => 'cbjobsearch-widget' );
		/* Create the widget. */
		$this->WP_Widget( 'cbjobsearch-widget', 'CB Job Search', $widget_ops, $control_ops );
	}
	
	function widget( $args, $instance ) {
		$options = get_option('careerbuilder_jobs_options');
		$bloghome = get_bloginfo('wpurl');
		$cb_jobresults_page = $options['cb_jobresults_page'];
		$gen_value = strtolower(get_query_var('job_no_prefix'));
		$search_location = get_query_var('location');
		$search_keyword = get_query_var('keyword');
		if ( !$gen_value ) {
			$location_value = strtolower(get_query_var('job_location'));
			$category_value = strtolower(get_query_var('job_category'));
			$company_value = strtolower(get_query_var('job_company'));
		} else {
			$category_value = CB_JobSearch::get_cb_category( $gen_value );
			if ( $category_value != false ) {
				$category_value = strtolower(get_query_var('job_no_prefix'));
			} else {
				$location_value = strtolower(get_query_var('job_no_prefix'));
			}
		}
		$cb_permalinks = $options['cb_permalinks'];
		if ( $location_value ) {
			$cb_location_prefix = $options['cb_location_prefix'];	
			// if there is a prefix
			if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
				if ( $cb_permalinks == 1 ) {
					// rules for directory with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_location_prefix.'/'.$location_value;
				} else if ( $cb_permalinks == 3 ) {
					// rules for hyphenated with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_location_prefix.'/'.$location_value;
				}
			// if there is no prefix
			} else {
				if ( $cb_permalinks == 2 ) {
					// rules for directory
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$location_value;	
				} else if ( $cb_permalinks == 4 ) {
					// rules for hyphenated
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-in-'.$location_value;
				}
			}
		} else if ( $company_value ) {
			$cb_company_prefix = $options['cb_company_prefix'];
			// if there is a prefix
			if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
				if ( $cb_permalinks == 1 ) {
					// rules for directory with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_company_prefix.'/'.$company_value;
				} else if ( $cb_permalinks == 3 ) {
					// rules for hyphenated with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_company_prefix.'/'.$company_value;
				}
			// if there is no prefix
			} else {
				if ( $cb_permalinks == 2 ) {
					// rules for directory
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_company_prefix.'/'.$company_value;
				} else if ( $cb_permalinks == 4 ) {
					// rules for hyphenated
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-at-'.$company_value;
				}
			}
		} else if ( $category_value ) {
			$cb_category_prefix = $options['cb_category_prefix'];
			// if there is a prefix
			if ( $cb_permalinks == 1 || $cb_permalinks == 3 ) {
				if ( $cb_permalinks == 1 ) {
					// rules for directory with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$cb_category_prefix.'/'.$category_value;					
				} else if ( $cb_permalinks == 3 ) {
					// rules for hyphenated with prefixes
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-by-'.$cb_category_prefix.'/'.$category_value;
				}
			// if there is no prefix
			} else {
				// need to get all query vars and see what the site calls them
				if ( $cb_permalinks == 2 ) {
					// rules for directory
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'/'.$category_value;
				} else if ( $cb_permalinks == 4 ) {
					// rules for hyphenated
					$url['results_root'] = $bloghome.'/'.$cb_jobresults_page.'-in-'.$category_value;
				}
			}
		} else if ( $search_location || $search_keyword ) {
			$url['results_root'] = $bloghome.'/'.$cb_jobresults_page;
		}
		extract( $args );

		/* User-selected settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$buttonlabel = $instance['buttonlabel'];

		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Title of widget (before and after defined by themes). */
		if ( $title )
			echo $before_title . $title . $after_title;
		?>
		<form id="jobsearchform" name="jobsearchform" method="get" action="<?php echo $url['results_root']; ?>">
			<label for="keyword"><?php echo __('Keywords', 'careerbuilder_jobs'); ?></label>
			<input id="keyword" name="keyword" value="" />
			<label for="location"><?php echo __('Location', 'careerbuilder_jobs'); ?></label>
			<input id="location" name="location" value="" />
			<input id="jobsearchsubmit" type="submit" value="<?php echo $buttonlabel; ?>" />
		</form>
		<?php
		/* After widget (defined by themes). */
		echo $after_widget;
	}
	
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags (if needed) and update the widget settings. */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['buttonlabel'] = strip_tags( $new_instance['buttonlabel'] );
		return $instance;
	}
	
	function form( $instance ) {
		/* Set up some default widget settings. */
		$defaults = array( 'title' => '', 'formlabel' => '', 'buttonlabel' => '');		$instance = wp_parse_args( (array) $instance, $defaults );
	?>
	<p>
			<label for="<?php echo $this->get_field_id('title'); ?>">Title:</label>
			<input id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $instance['title']; ?>" style="width:100%;" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('buttonlabel'); ?>">Button Label:</label>
			<input id="<?php echo $this->get_field_id('buttonlabel'); ?>" name="<?php echo $this->get_field_name('buttonlabel'); ?>" value="<?php echo $instance['buttonlabel']; ?>" />
		</p>
		<?php
	}
}

if ( class_exists( 'CB_JobSearch' ) ) {
	$CB_JobSearch = new CB_JobSearch();
}


/**
 * Hooks into WordPress 
 */
 
if ( isset( $CB_JobSearch ) ) {


add_action('generate_rewrite_rules', array('CB_JobSearch', 'job_add_rewrite_rules'));
//add_action('init', array('CB_JobSearch', 'init'));
add_action('init', array('CB_JobSearch', 'job_flush_rewrite'));
add_action('wp_print_styles', array('CB_JobSearch', 'add_cb_stylesheet'));
add_action('wp_print_scripts', array('CB_JobSearch', 'add_cb_javascript'));
add_filter('query_vars', array('CB_JobSearch', 'job_no_prefix'));
add_action('do_feed_jobs', array('CB_JobSearch', 'write_job_feed'), 10, 1);
add_action('admin_menu', array('CB_JobSearch', 'add_settings_page'));
add_action('admin_init', array('CB_JobSearch', 'cbjobs_admin_init'));
add_action('admin_print_styles', array('CB_JobSearch', 'cb_admin_styles'));
add_action('admin_print_scripts', array('CB_JobSearch', 'cb_admin_scripts'));
add_action( 'widgets_init', array('CB_JobSearch', 'cb_load_widgets'));
add_filter("plugin_action_links_" . plugin_basename(__FILE__), array('CB_JobSearch', 'settings_link') );
add_filter('single_post_title', array('CB_JobSearch', 'replace_title'), 10, 3);
add_filter('wp_head', array('CB_JobSearch', 'wphead_content'), 10, 3);
register_deactivation_hook( __FILE__,  array('CB_JobSearch', 'deactivate'));
}
?>